@@ -543,19 +543,6 @@ pub enum FillNullStrategy {
     /// replace with the minimal value of that data type
     MinBound,
 }
-
-/// Replace None values with various strategies
-pub trait ChunkFillNull {
-    /// Replace None values with one of the following strategies:
-    /// * Forward fill (replace None with the previous value)
-    /// * Backward fill (replace None with the next value)
-    /// * Mean fill (replace None with the mean of the whole array)
-    /// * Min fill (replace None with the minimum of the whole array)
-    /// * Max fill (replace None with the maximum of the whole array)
-    fn fill_null(&self, strategy: FillNullStrategy) -> PolarsResult<Self>
-    where
-        Self: Sized;
-}
 /// Replace None values with a value
 pub trait ChunkFillNullValue<T> {
     /// Replace None values with a give value `T`.
@@ -734,18 +721,6 @@ pub trait IsIn {
     }
 }
 
-/// Argmin/ Argmax
-pub trait ArgAgg {
-    /// Get the index of the minimal value
-    fn arg_min(&self) -> Option<usize> {
-        None
-    }
-    /// Get the index of the maximal value
-    fn arg_max(&self) -> Option<usize> {
-        None
-    }
-}
-
 /// Repeat the values `n` times.
 #[cfg(feature = "repeat_by")]
 pub trait RepeatBy {
