@@ -2,6 +2,7 @@
 use std::borrow::Cow;
 use std::fmt;
 use std::fmt::{Debug, Display, Formatter};
+use std::sync::atomic::{AtomicU8, Ordering};
 
 #[cfg(any(
     feature = "dtype-date",
@@ -9,9 +10,12 @@ use std::fmt::{Debug, Display, Formatter};
     feature = "dtype-time"
 ))]
 use arrow::temporal_conversions::*;
+use chrono::NaiveDateTime;
 #[cfg(feature = "timezones")]
 use chrono::TimeZone;
 #[cfg(any(feature = "fmt", feature = "fmt_no_tty"))]
+use comfy_table::modifiers::*;
+#[cfg(any(feature = "fmt", feature = "fmt_no_tty"))]
 use comfy_table::presets::*;
 #[cfg(any(feature = "fmt", feature = "fmt_no_tty"))]
 use comfy_table::*;
@@ -22,6 +26,26 @@ use crate::prelude::*;
 
 const LIMIT: usize = 25;
 
+#[derive(Copy, Clone)]
+#[repr(u8)]
+pub enum FloatFmt {
+    Mixed,
+    Full,
+}
+static FLOAT_FMT: AtomicU8 = AtomicU8::new(FloatFmt::Mixed as u8);
+
+fn get_float_fmt() -> FloatFmt {
+    match FLOAT_FMT.load(Ordering::Relaxed) {
+        0 => FloatFmt::Mixed,
+        1 => FloatFmt::Full,
+        _ => panic!(),
+    }
+}
+
+pub fn set_float_fmt(fmt: FloatFmt) {
+    FLOAT_FMT.store(fmt as u8, Ordering::Relaxed)
+}
+
 macro_rules! format_array {
     ($f:ident, $a:expr, $dtype:expr, $name:expr, $array_type:expr) => {{
         write!(
@@ -256,7 +280,8 @@ impl Debug for Series {
                 format_array!(f, self.duration().unwrap(), &dt, self.name(), "Series")
             }
             DataType::List(_) => {
-                format_array!(f, self.list().unwrap(), "list", self.name(), "Series")
+                let dt = format!("{}", self.dtype());
+                format_array!(f, self.list().unwrap(), &dt, self.name(), "Series")
             }
             #[cfg(feature = "object")]
             DataType::Object(_) => format_object_array(f, self, self.name(), "Series"),
@@ -421,25 +446,25 @@ impl Display for DataFrame {
                 names.push(s);
                 constraints.push(tbl_lower_bounds(l));
             }
-            let preset = match std::env::var(FMT_TABLE_FORMATTING)
+            let (preset, is_utf8) = match std::env::var(FMT_TABLE_FORMATTING)
                 .as_deref()
                 .unwrap_or("DEFAULT")
             {
-                "ASCII_FULL" => ASCII_FULL,
-                "ASCII_FULL_CONDENSED" => ASCII_FULL_CONDENSED,
-                "ASCII_NO_BORDERS" => ASCII_NO_BORDERS,
-                "ASCII_BORDERS_ONLY" => ASCII_BORDERS_ONLY,
-                "ASCII_BORDERS_ONLY_CONDENSED" => ASCII_BORDERS_ONLY_CONDENSED,
-                "ASCII_HORIZONTAL_ONLY" => ASCII_HORIZONTAL_ONLY,
-                "ASCII_MARKDOWN" => ASCII_MARKDOWN,
-                "UTF8_FULL" => UTF8_FULL,
-                "UTF8_FULL_CONDENSED" => UTF8_FULL_CONDENSED,
-                "UTF8_NO_BORDERS" => UTF8_NO_BORDERS,
-                "UTF8_BORDERS_ONLY" => UTF8_BORDERS_ONLY,
-                "UTF8_HORIZONTAL_ONLY" => UTF8_HORIZONTAL_ONLY,
-                "NOTHING" => NOTHING,
-                "DEFAULT" => UTF8_FULL_CONDENSED,
-                _ => UTF8_FULL_CONDENSED,
+                "ASCII_FULL" => (ASCII_FULL, false),
+                "ASCII_FULL_CONDENSED" => (ASCII_FULL_CONDENSED, false),
+                "ASCII_NO_BORDERS" => (ASCII_NO_BORDERS, false),
+                "ASCII_BORDERS_ONLY" => (ASCII_BORDERS_ONLY, false),
+                "ASCII_BORDERS_ONLY_CONDENSED" => (ASCII_BORDERS_ONLY_CONDENSED, false),
+                "ASCII_HORIZONTAL_ONLY" => (ASCII_HORIZONTAL_ONLY, false),
+                "ASCII_MARKDOWN" => (ASCII_MARKDOWN, false),
+                "UTF8_FULL" => (UTF8_FULL, true),
+                "UTF8_FULL_CONDENSED" => (UTF8_FULL_CONDENSED, true),
+                "UTF8_NO_BORDERS" => (UTF8_NO_BORDERS, true),
+                "UTF8_BORDERS_ONLY" => (UTF8_BORDERS_ONLY, true),
+                "UTF8_HORIZONTAL_ONLY" => (UTF8_HORIZONTAL_ONLY, true),
+                "NOTHING" => (NOTHING, false),
+                "DEFAULT" => (UTF8_FULL_CONDENSED, true),
+                _ => (UTF8_FULL_CONDENSED, true),
             };
 
             let mut table = Table::new();
@@ -447,6 +472,9 @@ impl Display for DataFrame {
                 .load_preset(preset)
                 .set_content_arrangement(ContentArrangement::Dynamic);
 
+            if is_utf8 && env_is_true(FMT_TABLE_ROUNDED_CORNERS) {
+                table.apply_modifier(UTF8_ROUND_CORNERS);
+            }
             if max_n_rows > 0 {
                 if height > max_n_rows {
                     let mut rows = Vec::with_capacity(std::cmp::max(max_n_rows, 2));
@@ -573,6 +601,10 @@ fn fmt_integer<T: Num + NumCast + Display>(
 const SCIENTIFIC_BOUND: f64 = 999999.0;
 fn fmt_float<T: Num + NumCast>(f: &mut Formatter<'_>, width: usize, v: T) -> fmt::Result {
     let v: f64 = NumCast::from(v).unwrap();
+    if matches!(get_float_fmt(), FloatFmt::Full) {
+        return write!(f, "{v:>width$}");
+    }
+
     // show integers as 0.0, 1.0 ... 101.0
     if v.fract() == 0.0 && v.abs() < SCIENTIFIC_BOUND {
         write!(f, "{v:>width$.1}")
@@ -709,28 +741,8 @@ impl Display for AnyValue<'_> {
                 };
                 match tz {
                     None => write!(f, "{ndt}"),
-                    Some(_tz) => {
-                        #[cfg(feature = "timezones")]
-                        {
-                            match _tz.parse::<chrono_tz::Tz>() {
-                                Ok(tz) => {
-                                    let dt_utc = chrono::Utc.from_local_datetime(&ndt).unwrap();
-                                    let dt_tz_aware = dt_utc.with_timezone(&tz);
-                                    write!(f, "{dt_tz_aware}")
-                                }
-                                Err(_) => match parse_offset(_tz) {
-                                    Ok(offset) => {
-                                        let dt_tz_aware = offset.from_utc_datetime(&ndt);
-                                        write!(f, "{dt_tz_aware}")
-                                    }
-                                    Err(_) => write!(f, "invalid timezone"),
-                                },
-                            }
-                        }
-                        #[cfg(not(feature = "timezones"))]
-                        {
-                            panic!("activate 'timezones' feature")
-                        }
+                    Some(tz) => {
+                        write!(f, "{}", PlTzAware::new(ndt, tz))
                     }
                 }
             }
@@ -746,12 +758,8 @@ impl Display for AnyValue<'_> {
                 write!(f, "{nt}")
             }
             #[cfg(feature = "dtype-categorical")]
-            AnyValue::Categorical(idx, rev, arr) => {
-                let s = if arr.is_null() {
-                    rev.get(*idx)
-                } else {
-                    unsafe { arr.deref_unchecked().value(*idx as usize) }
-                };
+            AnyValue::Categorical(_, _, _) => {
+                let s = self.get_str().unwrap();
                 write!(f, "\"{s}\"")
             }
             AnyValue::List(s) => write!(f, "{}", s.fmt_list()),
@@ -771,6 +779,43 @@ impl Display for AnyValue<'_> {
     }
 }
 
+/// Utility struct to format a timezone aware datetime.
+#[allow(dead_code)]
+pub struct PlTzAware<'a> {
+    ndt: NaiveDateTime,
+    tz: &'a str,
+}
+impl<'a> PlTzAware<'a> {
+    pub fn new(ndt: NaiveDateTime, tz: &'a str) -> Self {
+        Self { ndt, tz }
+    }
+}
+
+impl Display for PlTzAware<'_> {
+    #[allow(unused_variables)]
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
+        #[cfg(feature = "timezones")]
+        match self.tz.parse::<chrono_tz::Tz>() {
+            Ok(tz) => {
+                let dt_utc = chrono::Utc.from_local_datetime(&self.ndt).unwrap();
+                let dt_tz_aware = dt_utc.with_timezone(&tz);
+                write!(f, "{dt_tz_aware}")
+            }
+            Err(_) => match parse_offset(self.tz) {
+                Ok(offset) => {
+                    let dt_tz_aware = offset.from_utc_datetime(&self.ndt);
+                    write!(f, "{dt_tz_aware}")
+                }
+                Err(_) => write!(f, "invalid timezone"),
+            },
+        }
+        #[cfg(not(feature = "timezones"))]
+        {
+            panic!("activate 'timezones' feature")
+        }
+    }
+}
+
 #[cfg(feature = "dtype-struct")]
 fn fmt_struct(f: &mut Formatter<'_>, vals: &[AnyValue]) -> fmt::Result {
     write!(f, "{{")?;
@@ -917,7 +962,7 @@ mod test {
 
         assert_eq!(
             r#"shape: (2,)
-Series: 'a' [list]
+Series: 'a' [list[i32]]
 [
 	[1, 2, 3]
 	null
