@@ -69,11 +69,8 @@ where
                     None
                 };
 
-                let array = PrimitiveArray::from_data(
-                    T::get_dtype().to_arrow(),
-                    list_values.into(),
-                    validity,
-                );
+                let array =
+                    PrimitiveArray::new(T::get_dtype().to_arrow(), list_values.into(), validity);
                 let data_type = ListArray::<i64>::default_datatype(T::get_dtype().to_arrow());
                 // Safety:
                 // offsets are monotonically increasing
@@ -84,7 +81,7 @@ where
                     None,
                 );
 
-                let mut ca = ListChunked::from_chunks(self.name(), vec![Box::new(arr)]);
+                let mut ca = unsafe { ListChunked::from_chunks(self.name(), vec![Box::new(arr)]) };
                 if can_fast_explode {
                     ca.set_fast_explode()
                 }
@@ -132,11 +129,8 @@ where
                     None
                 };
 
-                let array = PrimitiveArray::from_data(
-                    T::get_dtype().to_arrow(),
-                    list_values.into(),
-                    validity,
-                );
+                let array =
+                    PrimitiveArray::new(T::get_dtype().to_arrow(), list_values.into(), validity);
                 let data_type = ListArray::<i64>::default_datatype(T::get_dtype().to_arrow());
                 let arr = ListArray::<i64>::new(
                     data_type,
@@ -144,7 +138,7 @@ where
                     Box::new(array),
                     None,
                 );
-                let mut ca = ListChunked::from_chunks(self.name(), vec![Box::new(arr)]);
+                let mut ca = unsafe { ListChunked::from_chunks(self.name(), vec![Box::new(arr)]) };
                 if can_fast_explode {
                     ca.set_fast_explode()
                 }
@@ -265,7 +259,7 @@ fn agg_list_list<F: Fn(&ListChunked, bool, &mut Vec<i64>, &mut i64, &mut Vec<Arr
             None,
         )) as ArrayRef
     };
-    let mut listarr = ListChunked::from_chunks(ca.name(), vec![arr]);
+    let mut listarr = unsafe { ListChunked::from_chunks(ca.name(), vec![arr]) };
     if can_fast_explode {
         listarr.set_fast_explode()
     }
@@ -398,7 +392,7 @@ impl<T: PolarsObject> AggList for ObjectChunked<T> {
             None,
         )) as ArrayRef;
 
-        let mut listarr = ListChunked::from_chunks(self.name(), vec![arr]);
+        let mut listarr = unsafe { ListChunked::from_chunks(self.name(), vec![arr]) };
         if can_fast_explode {
             listarr.set_fast_explode()
         }
