@@ -74,8 +74,8 @@ impl private::PrivateSeries for SeriesWrap<CategoricalChunked> {
         .into_series()
     }
 
-    fn _set_sorted(&mut self, is_sorted: IsSorted) {
-        self.0.logical_mut().set_sorted2(is_sorted)
+    fn _set_sorted_flag(&mut self, is_sorted: IsSorted) {
+        self.0.logical_mut().set_sorted_flag(is_sorted)
     }
 
     unsafe fn equal_element(&self, idx_self: usize, idx_other: usize, other: &Series) -> bool {
@@ -146,10 +146,10 @@ impl private::PrivateSeries for SeriesWrap<CategoricalChunked> {
 }
 
 impl SeriesTrait for SeriesWrap<CategoricalChunked> {
-    fn is_sorted(&self) -> IsSorted {
-        if self.0.logical().is_sorted() {
+    fn is_sorted_flag(&self) -> IsSorted {
+        if self.0.logical().is_sorted_flag() {
             IsSorted::Ascending
-        } else if self.0.logical().is_sorted_reverse() {
+        } else if self.0.logical().is_sorted_reverse_flag() {
             IsSorted::Descending
         } else {
             IsSorted::Not
@@ -351,11 +351,6 @@ impl SeriesTrait for SeriesWrap<CategoricalChunked> {
         self.with_state(false, |ca| ca.shift(periods)).into_series()
     }
 
-    fn fill_null(&self, strategy: FillNullStrategy) -> PolarsResult<Series> {
-        self.try_with_state(false, |cats| cats.fill_null(strategy))
-            .map(|ca| ca.into_series())
-    }
-
     fn _sum_as_series(&self) -> Series {
         CategoricalChunked::full_null(self.0.logical().name(), 1).into_series()
     }
@@ -403,11 +398,6 @@ impl SeriesTrait for SeriesWrap<CategoricalChunked> {
         casted.list().unwrap().clone()
     }
 
-    #[cfg(feature = "is_first")]
-    fn is_first(&self) -> PolarsResult<BooleanChunked> {
-        self.0.logical().is_first()
-    }
-
     #[cfg(feature = "mode")]
     fn mode(&self) -> PolarsResult<Series> {
         Ok(CategoricalChunked::full_null(self.0.logical().name(), 1).into_series())
