@@ -161,7 +161,7 @@ impl private::PrivateSeries for SeriesWrap<DatetimeChunked> {
     }
     fn divide(&self, _rhs: &Series) -> PolarsResult<Series> {
         Err(PolarsError::ComputeError(
-            "cannot do division on logical".into(),
+            "Cannot divide Series of dtype: 'Datetime'.".into(),
         ))
     }
     fn remainder(&self, _rhs: &Series) -> PolarsResult<Series> {
@@ -398,14 +398,6 @@ impl SeriesTrait for SeriesWrap<DatetimeChunked> {
         self.0.arg_unique()
     }
 
-    fn arg_min(&self) -> Option<usize> {
-        self.0.arg_min()
-    }
-
-    fn arg_max(&self) -> Option<usize> {
-        self.0.arg_max()
-    }
-
     fn is_null(&self) -> BooleanChunked {
         self.0.is_null()
     }
@@ -440,13 +432,6 @@ impl SeriesTrait for SeriesWrap<DatetimeChunked> {
             .into_series()
     }
 
-    fn fill_null(&self, strategy: FillNullStrategy) -> PolarsResult<Series> {
-        self.0.fill_null(strategy).map(|ca| {
-            ca.into_datetime(self.0.time_unit(), self.0.time_zone().clone())
-                .into_series()
-        })
-    }
-
     fn _sum_as_series(&self) -> Series {
         Int32Chunked::full_null(self.name(), 1)
             .cast(self.dtype())
@@ -519,11 +504,6 @@ impl SeriesTrait for SeriesWrap<DatetimeChunked> {
             .unwrap()
             .clone()
     }
-    #[cfg(feature = "is_first")]
-    fn is_first(&self) -> PolarsResult<BooleanChunked> {
-        self.0.is_first()
-    }
-
     #[cfg(feature = "mode")]
     fn mode(&self) -> PolarsResult<Series> {
         self.0.mode().map(|ca| {
