@@ -11,6 +11,8 @@ mod categorical;
 mod dates_time;
 #[cfg(feature = "dtype-datetime")]
 mod datetime;
+#[cfg(feature = "dtype-i128")]
+mod decimal;
 #[cfg(feature = "dtype-duration")]
 mod duration;
 mod floats;
@@ -419,14 +421,6 @@ macro_rules! impl_dyn_series {
                 ChunkUnique::arg_unique(&self.0)
             }
 
-            fn arg_min(&self) -> Option<usize> {
-                ArgAgg::arg_min(&self.0)
-            }
-
-            fn arg_max(&self) -> Option<usize> {
-                ArgAgg::arg_max(&self.0)
-            }
-
             fn is_null(&self) -> BooleanChunked {
                 self.0.is_null()
             }
@@ -455,10 +449,6 @@ macro_rules! impl_dyn_series {
                 ChunkShift::shift(&self.0, periods).into_series()
             }
 
-            fn fill_null(&self, strategy: FillNullStrategy) -> PolarsResult<Series> {
-                ChunkFillNull::fill_null(&self.0, strategy).map(|ca| ca.into_series())
-            }
-
             fn _sum_as_series(&self) -> Series {
                 ChunkAggSeries::sum_as_series(&self.0)
             }
@@ -514,11 +504,6 @@ macro_rules! impl_dyn_series {
                 self.0.checked_div(rhs)
             }
 
-            #[cfg(feature = "is_first")]
-            fn is_first(&self) -> PolarsResult<BooleanChunked> {
-                self.0.is_first()
-            }
-
             #[cfg(feature = "object")]
             fn as_any(&self) -> &dyn Any {
                 &self.0
