@@ -627,49 +627,51 @@ where
     // We use the hash to partition the keys to the matching hashtable.
     // Every thread traverses all keys/hashes and ignores the ones that doesn't fall in that partition.
     POOL.install(|| {
-        (0..n_partitions).into_par_iter().map(|partition_no| {
-            let build_hasher = build_hasher.clone();
-            let hashes_and_keys = &hashes_and_keys;
-            let partition_no = partition_no as u64;
-            let mut hash_tbl: HashMap<T, (bool, Vec<IdxSize>), RandomState> =
-                HashMap::with_hasher(build_hasher);
+        (0..n_partitions)
+            .into_par_iter()
+            .map(|partition_no| {
+                let build_hasher = build_hasher.clone();
+                let hashes_and_keys = &hashes_and_keys;
+                let partition_no = partition_no as u64;
+                let mut hash_tbl: HashMap<T, (bool, Vec<IdxSize>), RandomState> =
+                    HashMap::with_hasher(build_hasher);
 
-            let n_threads = n_partitions as u64;
-            let mut offset = 0;
-            for hashes_and_keys in hashes_and_keys {
-                let len = hashes_and_keys.len();
-                hashes_and_keys
-                    .iter()
-                    .enumerate()
-                    .for_each(|(idx, (h, k))| {
-                        let idx = idx as IdxSize;
-                        // partition hashes by thread no.
-                        // So only a part of the hashes go to this hashmap
-                        if this_partition(*h, partition_no, n_threads) {
-                            let idx = idx + offset;
-                            let entry = hash_tbl
-                                .raw_entry_mut()
-                                // uses the key to check equality to find and entry
-                                .from_key_hashed_nocheck(*h, k);
+                let n_threads = n_partitions as u64;
+                let mut offset = 0;
+                for hashes_and_keys in hashes_and_keys {
+                    let len = hashes_and_keys.len();
+                    hashes_and_keys
+                        .iter()
+                        .enumerate()
+                        .for_each(|(idx, (h, k))| {
+                            let idx = idx as IdxSize;
+                            // partition hashes by thread no.
+                            // So only a part of the hashes go to this hashmap
+                            if this_partition(*h, partition_no, n_threads) {
+                                let idx = idx + offset;
+                                let entry = hash_tbl
+                                    .raw_entry_mut()
+                                    // uses the key to check equality to find and entry
+                                    .from_key_hashed_nocheck(*h, k);
 
-                            match entry {
-                                RawEntryMut::Vacant(entry) => {
-                                    entry.insert_hashed_nocheck(*h, *k, (false, vec![idx]));
-                                }
-                                RawEntryMut::Occupied(mut entry) => {
-                                    let (_k, v) = entry.get_key_value_mut();
-                                    v.1.push(idx);
+                                match entry {
+                                    RawEntryMut::Vacant(entry) => {
+                                        entry.insert_hashed_nocheck(*h, *k, (false, vec![idx]));
+                                    }
+                                    RawEntryMut::Occupied(mut entry) => {
+                                        let (_k, v) = entry.get_key_value_mut();
+                                        v.1.push(idx);
+                                    }
                                 }
                             }
-                        }
-                    });
+                        });
 
-                offset += len as IdxSize;
-            }
-            hash_tbl
-        })
+                    offset += len as IdxSize;
+                }
+                hash_tbl
+            })
+            .collect()
     })
-    .collect()
 }
 
 pub(crate) fn create_hash_and_keys_threaded_vectorized<I, T>(
