@@ -39,5 +39,5 @@ pub(crate) fn prepare_expression_for_context(
     let lp = lp_arena.get(optimized);
     let aexpr = lp.get_exprs().pop().unwrap();
 
-    create_physical_expr(aexpr, ctxt, &expr_arena)
+    create_physical_expr(aexpr, ctxt, &expr_arena, None)
 }
