@@ -150,7 +150,11 @@ impl Display for FunctionExpr {
             #[cfg(all(feature = "rolling_window", feature = "moment"))]
             RollingSkew { .. } => "rolling_skew",
             ShiftAndFill { .. } => "shift_and_fill",
-            Nan(_) => "nan",
+            Nan(func) => match func {
+                NanFunction::IsNan => "is_nan",
+                NanFunction::IsNotNan => "is_not_nan",
+                NanFunction::DropNans => "drop_nans",
+            },
             #[cfg(feature = "round_series")]
             Clip { min, max } => match (min, max) {
                 (Some(_), Some(_)) => "clip",
@@ -193,7 +197,7 @@ macro_rules! wrap {
 macro_rules! map_as_slice {
     ($func:path) => {{
         let f = move |s: &mut [Series]| {
-            $func(s)
+            $func(s).map(Some)
         };
 
         SpecialEq::new(Arc::new(f))
@@ -201,7 +205,7 @@ macro_rules! map_as_slice {
 
     ($func:path, $($args:expr),*) => {{
         let f = move |s: &mut [Series]| {
-            $func(s, $($args),*)
+            $func(s, $($args),*).map(Some)
         };
 
         SpecialEq::new(Arc::new(f))
@@ -215,7 +219,7 @@ macro_rules! map_owned {
     ($func:path) => {{
         let f = move |s: &mut [Series]| {
             let s = std::mem::take(&mut s[0]);
-            $func(s)
+            $func(s).map(Some)
         };
 
         SpecialEq::new(Arc::new(f))
@@ -224,7 +228,7 @@ macro_rules! map_owned {
     ($func:path, $($args:expr),*) => {{
         let f = move |s: &mut [Series]| {
             let s = std::mem::take(&mut s[0]);
-            $func(s, $($args),*)
+            $func(s, $($args),*).map(Some)
         };
 
         SpecialEq::new(Arc::new(f))
@@ -237,7 +241,7 @@ macro_rules! map {
     ($func:path) => {{
         let f = move |s: &mut [Series]| {
             let s = &s[0];
-            $func(s)
+            $func(s).map(Some)
         };
 
         SpecialEq::new(Arc::new(f))
@@ -246,7 +250,7 @@ macro_rules! map {
     ($func:path, $($args:expr),*) => {{
         let f = move |s: &mut [Series]| {
             let s = &s[0];
-            $func(s, $($args),*)
+            $func(s, $($args),*).map(Some)
         };
 
         SpecialEq::new(Arc::new(f))
@@ -260,7 +264,7 @@ impl From<FunctionExpr> for SpecialEq<Arc<dyn SeriesUdf>> {
             NullCount => {
                 let f = |s: &mut [Series]| {
                     let s = &s[0];
-                    Ok(Series::new(s.name(), [s.null_count() as IdxSize]))
+                    Ok(Some(Series::new(s.name(), [s.null_count() as IdxSize])))
                 };
                 wrap!(f)
             }
@@ -406,6 +410,8 @@ impl From<StringFunction> for SpecialEq<Arc<dyn SeriesUdf>> {
             Strip(matches) => map!(strings::strip, matches.as_deref()),
             LStrip(matches) => map!(strings::lstrip, matches.as_deref()),
             RStrip(matches) => map!(strings::rstrip, matches.as_deref()),
+            #[cfg(feature = "string_from_radix")]
+            FromRadix(matches) => map!(strings::from_radix, matches),
         }
     }
 }
@@ -429,6 +435,7 @@ impl From<BinaryFunction> for SpecialEq<Arc<dyn SeriesUdf>> {
 }
 
 #[cfg(feature = "temporal")]
+#[allow(deprecated)] // tz_localize
 impl From<TemporalFunction> for SpecialEq<Arc<dyn SeriesUdf>> {
     fn from(func: TemporalFunction) -> Self {
         use TemporalFunction::*;
@@ -451,7 +458,7 @@ impl From<TemporalFunction> for SpecialEq<Arc<dyn SeriesUdf>> {
             Truncate(every, offset) => map!(datetime::truncate, &every, &offset),
             Round(every, offset) => map!(datetime::round, &every, &offset),
             #[cfg(feature = "timezones")]
-            CastTimezone(tz) => map!(datetime::cast_timezone, &tz),
+            CastTimezone(tz) => map!(datetime::replace_timezone, tz.as_deref()),
             #[cfg(feature = "timezones")]
             TzLocalize(tz) => map!(datetime::tz_localize, &tz),
             Combine(tu) => map_as_slice!(temporal::combine, tu),
