@@ -23,7 +23,7 @@ use polars_io::{
 };
 
 use crate::logical_plan::functions::FunctionNode;
-use crate::logical_plan::projection::rewrite_projections;
+use crate::logical_plan::projection::{is_regex_projection, rewrite_projections};
 use crate::logical_plan::schema::{det_join_schema, FileInfo};
 use crate::prelude::*;
 use crate::utils;
@@ -46,17 +46,35 @@ impl From<LogicalPlan> for LogicalPlanBuilder {
     }
 }
 
+fn format_err(msg: &str, input: &LogicalPlan) -> String {
+    format!(
+        "{msg}\n\n> Error originated just after operation: '{input:?}'\n\
+    This operation could not be added to the plan.",
+    )
+}
+
+/// Returns every error or msg: &str as `ComputeError`.
+/// It also shows the logical plan node where the error
+/// originated.
+macro_rules! raise_err {
+    ($err:expr, $input:expr, $convert:ident) => {{
+        let format_err_outer = |msg: &str| format_err(msg, &$input);
+
+        let err = $err.wrap_msg(&format_err_outer);
+
+        LogicalPlan::Error {
+            input: Box::new($input.clone()),
+            err: err.into(),
+        }
+        .$convert()
+    }};
+}
+
 macro_rules! try_delayed {
     ($fallible:expr, $input:expr, $convert:ident) => {
         match $fallible {
             Ok(success) => success,
-            Err(err) => {
-                return LogicalPlan::Error {
-                    input: Box::new($input.clone()),
-                    err: err.into(),
-                }
-                .$convert()
-            }
+            Err(err) => return raise_err!(err, $input, $convert),
         }
     };
 }
@@ -97,7 +115,6 @@ impl LogicalPlanBuilder {
     }
 
     #[cfg(any(feature = "parquet", feature = "parquet_async"))]
-    #[cfg_attr(docsrs, doc(cfg(feature = "parquet")))]
     #[allow(clippy::too_many_arguments)]
     pub fn scan_parquet<P: Into<PathBuf>>(
         path: P,
@@ -160,7 +177,6 @@ impl LogicalPlanBuilder {
     }
 
     #[cfg(feature = "ipc")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "ipc")))]
     pub fn scan_ipc<P: Into<PathBuf>>(path: P, options: IpcScanOptions) -> PolarsResult<Self> {
         use polars_io::SerReader as _;
 
@@ -369,6 +385,14 @@ impl LogicalPlanBuilder {
         .into()
     }
 
+    pub fn add_err(self, err: PolarsError) -> Self {
+        LogicalPlan::Error {
+            input: Box::new(self.0),
+            err: err.into(),
+        }
+        .into()
+    }
+
     pub fn with_context(self, contexts: Vec<LogicalPlan>) -> Self {
         let mut schema = try_delayed!(self.0.schema(), &self.0, into)
             .as_ref()
@@ -380,7 +404,7 @@ impl LogicalPlanBuilder {
 
             for fld in other_schema.iter_fields() {
                 if schema.get(fld.name()).is_none() {
-                    schema.with_column(fld.name, fld.dtype)
+                    schema.with_column(fld.name, fld.dtype);
                 }
             }
         }
@@ -395,8 +419,10 @@ impl LogicalPlanBuilder {
     /// Apply a filter
     pub fn filter(self, predicate: Expr) -> Self {
         let predicate = if has_expr(&predicate, |e| match e {
-            Expr::Column(name) => name.starts_with('^') && name.ends_with('$'),
-            Expr::Wildcard | Expr::RenameAlias { .. } | Expr::Columns(_) => true,
+            Expr::Column(name) => is_regex_projection(name),
+            Expr::Wildcard | Expr::RenameAlias { .. } | Expr::Columns(_) | Expr::DtypeColumn(_) => {
+                true
+            }
             _ => false,
         }) {
             let schema = try_delayed!(self.0.schema(), &self.0, into);
@@ -405,6 +431,12 @@ impl LogicalPlanBuilder {
                 &self.0,
                 into
             );
+            if rewritten.is_empty() {
+                let msg = "The predicate expanded to zero expressions. \
+                This may for example be caused by a regex not matching column names or \
+                a column dtype match not hitting any dtypes in the DataFrame";
+                return raise_err!(PolarsError::ComputeError(msg.into()), &self.0, into);
+            }
             combine_predicates_expr(rewritten.into_iter())
         } else {
             predicate
@@ -478,7 +510,7 @@ impl LogicalPlanBuilder {
                 let dtype = try_delayed!(
                     current_schema
                         .get(name)
-                        .ok_or_else(|| PolarsError::NotFound(name.to_string().into())),
+                        .ok_or_else(|| PolarsError::ColumnNotFound(name.to_string().into())),
                     self.0,
                     into
                 );
@@ -552,7 +584,7 @@ impl LogicalPlanBuilder {
                 if let Expr::Column(name) = e {
                     if let Some(DataType::List(inner)) = schema.get(name) {
                         let inner = *inner.clone();
-                        schema.with_column(name.to_string(), inner)
+                        schema.with_column(name.to_string(), inner);
                     }
 
                     (**name).to_owned()
@@ -604,6 +636,19 @@ impl LogicalPlanBuilder {
         right_on: Vec<Expr>,
         options: JoinOptions,
     ) -> Self {
+        for e in left_on.iter().chain(right_on.iter()) {
+            if has_expr(e, |e| matches!(e, Expr::Alias(_, _))) {
+                return LogicalPlan::Error {
+                    input: Box::new(self.0),
+                    err: PolarsError::ComputeError(
+                        "'alias' is not allowed in a join key. Use 'with_columns' first.".into(),
+                    )
+                    .into(),
+                }
+                .into();
+            }
+        }
+
         let schema_left = try_delayed!(self.0.schema(), &self.0, into);
         let schema_right = try_delayed!(other.schema(), &self.0, into);
 
@@ -650,6 +695,7 @@ impl LogicalPlanBuilder {
                 schema,
                 predicate_pd: optimizations.predicate_pushdown,
                 projection_pd: optimizations.projection_pushdown,
+                streamable: optimizations.streaming,
                 fmt_str: name,
             },
         }
