@@ -76,6 +76,7 @@ impl LiteralValue {
             Int64(v) => AnyValue::Int64(*v),
             Float32(v) => AnyValue::Float32(*v),
             Float64(v) => AnyValue::Float64(*v),
+            Utf8(v) => AnyValue::Utf8(v),
             _ => return None,
         };
         Some(av)
@@ -201,7 +202,17 @@ impl TryFrom<AnyValue<'_>> for LiteralValue {
             AnyValue::List(l) => Ok(Self::Series(SpecialEq::new(l))),
             AnyValue::Utf8Owned(o) => Ok(Self::Utf8(o.into())),
             #[cfg(feature = "dtype-categorical")]
-            AnyValue::Categorical(c, rev_mapping) => Ok(Self::Utf8(rev_mapping.get(c).to_string())),
+            AnyValue::Categorical(c, rev_mapping, arr) => {
+                if arr.is_null() {
+                    Ok(Self::Utf8(rev_mapping.get(c).to_string()))
+                } else {
+                    unsafe {
+                        Ok(Self::Utf8(
+                            arr.deref_unchecked().value(c as usize).to_string(),
+                        ))
+                    }
+                }
+            }
             _ => Err(PolarsError::ComputeError(
                 "Unsupported AnyValue type variant, cannot convert to Literal".into(),
             )),
