@@ -120,7 +120,6 @@ impl<T: NativeType> DatetimeInfer<T> {
     fn coerce_utf8(&mut self, ca: &Utf8Chunked) -> Series {
         let chunks = ca
             .downcast_iter()
-            .into_iter()
             .map(|array| {
                 let iter = array
                     .into_iter()
@@ -199,15 +198,15 @@ pub fn infer_pattern_single(val: &str) -> Option<Pattern> {
 }
 
 fn infer_pattern_datetime_single(val: &str) -> Option<Pattern> {
-    if patterns::DATETIME_D_M_Y
-        .iter()
-        .any(|fmt| NaiveDateTime::parse_from_str(val, fmt).is_ok())
-    {
+    if patterns::DATETIME_D_M_Y.iter().any(|fmt| {
+        NaiveDateTime::parse_from_str(val, fmt).is_ok()
+            || NaiveDate::parse_from_str(val, fmt).is_ok()
+    }) {
         Some(Pattern::DatetimeDMY)
-    } else if patterns::DATETIME_Y_M_D
-        .iter()
-        .any(|fmt| NaiveDateTime::parse_from_str(val, fmt).is_ok())
-    {
+    } else if patterns::DATETIME_Y_M_D.iter().any(|fmt| {
+        NaiveDateTime::parse_from_str(val, fmt).is_ok()
+            || NaiveDate::parse_from_str(val, fmt).is_ok()
+    }) {
         Some(Pattern::DatetimeYMD)
     } else {
         None
@@ -231,9 +230,13 @@ fn infer_pattern_date_single(val: &str) -> Option<Pattern> {
 }
 
 #[cfg(feature = "dtype-datetime")]
-pub(crate) fn to_datetime(ca: &Utf8Chunked, tu: TimeUnit) -> PolarsResult<DatetimeChunked> {
+pub(crate) fn to_datetime(
+    ca: &Utf8Chunked,
+    tu: TimeUnit,
+    tz: Option<&TimeZone>,
+) -> PolarsResult<DatetimeChunked> {
     match ca.first_non_null() {
-        None => Ok(Int64Chunked::full_null(ca.name(), ca.len()).into_datetime(tu, None)),
+        None => Ok(Int64Chunked::full_null(ca.name(), ca.len()).into_datetime(tu, tz.cloned())),
         Some(idx) => {
             let subset = ca.slice(idx as i64, ca.len());
             let pattern = subset
@@ -254,8 +257,12 @@ pub(crate) fn to_datetime(ca: &Utf8Chunked, tu: TimeUnit) -> PolarsResult<Dateti
             infer.coerce_utf8(ca).datetime().map(|ca| {
                 let mut ca = ca.clone();
                 ca.set_time_unit(tu);
-                ca
-            })
+                match tz {
+                    #[cfg(feature = "timezones")]
+                    Some(tz) => Ok(ca.replace_time_zone(Some(tz))?),
+                    _ => Ok(ca),
+                }
+            })?
         }
     }
 }
