@@ -89,7 +89,7 @@ fn test_err_no_found() {
 
     assert!(matches!(
         df.lazy().filter(col("nope").gt(lit(2))).collect(),
-        Err(PolarsError::NotFound(_))
+        Err(PolarsError::ColumnNotFound(_))
     ));
 }
 
@@ -153,6 +153,7 @@ fn test_projection_5086() -> PolarsResult<()> {
 }
 
 #[test]
+#[cfg(feature = "dtype-struct")]
 fn test_unnest_pushdown() -> PolarsResult<()> {
     let df = df![
         "collection" => Series::full_null("", 1, &DataType::Int32),
