@@ -3,6 +3,7 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Any, Mapping, Sequence, overload
 
 from polars.datatypes import N_INFER_DEFAULT, SchemaDefinition, SchemaDict
+from polars.dependencies import _PYARROW_AVAILABLE
 from polars.dependencies import numpy as np
 from polars.dependencies import pandas as pd
 from polars.dependencies import pyarrow as pa
@@ -176,10 +177,10 @@ def from_dicts(
 def from_records(
     data: Sequence[Sequence[Any]],
     schema: Sequence[str] | None = None,
-    orient: Orientation | None = None,
     *,
-    infer_schema_length: int | None = N_INFER_DEFAULT,
     schema_overrides: SchemaDict | None = None,
+    orient: Orientation | None = None,
+    infer_schema_length: int | None = N_INFER_DEFAULT,
 ) -> DataFrame:
     """
     Construct a DataFrame from a sequence of sequences. This operation clones data.
@@ -200,6 +201,9 @@ def from_records(
         If you supply a list of column names that does not match the names in the
         underlying data, the names given here will overwrite them. The number
         of names given in the schema should match the underlying data dimensions.
+    schema_overrides : dict, default None
+        Support type specification or override of one or more columns; note that
+        any dtypes inferred from the columns param will be overridden.
     orient : {None, 'col', 'row'}
         Whether to interpret two-dimensional data as columns or as rows. If None,
         the orientation is inferred by matching the columns and data dimensions. If
@@ -207,9 +211,6 @@ def from_records(
     infer_schema_length
         How many dictionaries/rows to scan to determine the data types
         if set to `None` all rows are scanned. This will be slow.
-    schema_overrides : dict, default None
-        Support type specification or override of one or more columns; note that
-        any dtypes inferred from the columns param will be overridden.
 
     Returns
     -------
@@ -245,8 +246,9 @@ def from_records(
 def from_numpy(
     data: np.ndarray[Any, Any],
     schema: SchemaDefinition | None = None,
-    orient: Orientation | None = None,
+    *,
     schema_overrides: SchemaDict | None = None,
+    orient: Orientation | None = None,
 ) -> DataFrame:
     """
     Construct a DataFrame from a numpy ndarray. This operation clones data.
@@ -267,13 +269,13 @@ def from_numpy(
         If you supply a list of column names that does not match the names in the
         underlying data, the names given here will overwrite them. The number
         of names given in the schema should match the underlying data dimensions.
+    schema_overrides : dict, default None
+        Support type specification or override of one or more columns; note that
+        any dtypes inferred from the columns param will be overridden.
     orient : {None, 'col', 'row'}
         Whether to interpret two-dimensional data as columns or as rows. If None,
         the orientation is inferred by matching the columns and data dimensions. If
         this does not yield conclusive results, column orientation is used.
-    schema_overrides : dict, default None
-        Support type specification or override of one or more columns; note that
-        any dtypes inferred from the columns param will be overridden.
 
     Returns
     -------
@@ -334,7 +336,6 @@ def from_arrow(
         If you supply a list of column names that does not match the names in the
         underlying data, the names given here will overwrite them. The number
         of names given in the schema should match the underlying data dimensions.
-
     schema_overrides : dict, default None
         Support type specification or override of one or more columns; note that
         any dtypes inferred from the schema param will be overridden.
@@ -391,7 +392,7 @@ def from_arrow(
 def from_pandas(
     df: pd.DataFrame,
     rechunk: bool = True,
-    nan_to_none: bool = True,
+    nan_to_null: bool = True,
     schema_overrides: SchemaDict | None = None,
 ) -> DataFrame:
     ...
@@ -401,16 +402,17 @@ def from_pandas(
 def from_pandas(
     df: pd.Series | pd.DatetimeIndex,
     rechunk: bool = True,
-    nan_to_none: bool = True,
+    nan_to_null: bool = True,
     schema_overrides: SchemaDict | None = None,
 ) -> Series:
     ...
 
 
+@deprecated_alias(nan_to_none="nan_to_null")
 def from_pandas(
     df: pd.DataFrame | pd.Series | pd.DatetimeIndex,
     rechunk: bool = True,
-    nan_to_none: bool = True,
+    nan_to_null: bool = True,
     schema_overrides: SchemaDict | None = None,
 ) -> DataFrame | Series:
     """
@@ -426,7 +428,7 @@ def from_pandas(
         Data represented as a pandas DataFrame, Series, or DatetimeIndex.
     rechunk : bool, default True
         Make sure that all data is in contiguous memory.
-    nan_to_none : bool, default True
+    nan_to_null : bool, default True
         If data contains `NaN` values PyArrow will convert the ``NaN`` to ``None``
     schema_overrides : dict, default None
         Support override of inferred types for one or more columns.
@@ -469,13 +471,60 @@ def from_pandas(
 
     """
     if isinstance(df, (pd.Series, pd.DatetimeIndex)):
-        return Series._from_pandas("", df, nan_to_none=nan_to_none)
+        return Series._from_pandas("", df, nan_to_null=nan_to_null)
     elif isinstance(df, pd.DataFrame):
         return DataFrame._from_pandas(
             df,
             rechunk=rechunk,
-            nan_to_none=nan_to_none,
+            nan_to_null=nan_to_null,
             schema_overrides=schema_overrides,
         )
     else:
         raise ValueError(f"Expected pandas DataFrame or Series, got {type(df)}.")
+
+
+def from_dataframe(df: Any, allow_copy: bool = True) -> DataFrame:
+    """
+    Build a Polars DataFrame from any dataframe supporting the interchange protocol.
+
+    Parameters
+    ----------
+    df
+        Object supporting the dataframe interchange protocol, i.e. must have implemented
+        the ``__dataframe__`` method.
+    allow_copy
+        Allow memory to be copied to perform the conversion. If set to False, causes
+        conversions that are not zero-copy to fail.
+
+    Notes
+    -----
+    Details on the dataframe interchange protocol:
+    https://data-apis.org/dataframe-protocol/latest/index.html
+
+    Zero-copy conversions currently cannot be guaranteed and will throw a
+    ``NotImplementedError``.
+
+    Using a dedicated function like :func:`from_pandas` or :func:`from_arrow` is a more
+    efficient method of conversion.
+
+    """
+    if isinstance(df, DataFrame):
+        return df
+    if not hasattr(df, "__dataframe__"):
+        raise TypeError(
+            f"`df` of type {type(df)} does not support the dataframe interchange"
+            " protocol."
+        )
+    if not _PYARROW_AVAILABLE or int(pa.__version__.split(".")[0]) < 11:
+        raise ImportError(
+            "pyarrow>=11.0.0 is required for converting a dataframe interchange object"
+            " to a Polars dataframe."
+        )
+    if not allow_copy:
+        raise NotImplementedError(
+            "Polars cannot guarantee zero-copy conversion from dataframe interchange"
+            " objects at this time."
+        )
+
+    pa_table = pa.interchange.from_dataframe(df, allow_copy=allow_copy)
+    return from_arrow(pa_table, rechunk=allow_copy)  # type: ignore[return-value]
