@@ -23,6 +23,7 @@ from typing import (
     overload,
 )
 
+from polars.dependencies import numpy as np
 from polars.dependencies import pyarrow as pa
 
 try:
@@ -85,12 +86,12 @@ PythonDataType: TypeAlias = Union[
     Type[Decimal],
 ]
 
-ColumnsType: TypeAlias = Union[
+SchemaDefinition: TypeAlias = Union[
     Sequence[str],
     Mapping[str, Union[PolarsDataType, PythonDataType]],
     Sequence[Union[str, Tuple[str, Union[PolarsDataType, PythonDataType, None]]]],
 ]
-Schema: TypeAlias = Mapping[str, PolarsDataType]
+SchemaDict: TypeAlias = Mapping[str, PolarsDataType]
 
 DTYPE_TEMPORAL_UNITS: frozenset[TimeUnit] = frozenset(["ns", "us", "ms"])
 
@@ -126,8 +127,7 @@ class DataTypeClass(type):
     def __repr__(cls) -> str:
         return cls.__name__
 
-    @classmethod
-    def string_repr(cls) -> str:
+    def _string_repr(cls) -> str:
         return dtype_str_repr(cls)
 
 
@@ -144,9 +144,8 @@ class DataType(metaclass=DataTypeClass):
     def __reduce__(self) -> Any:
         return (_custom_reconstruct, (type(self), object, None), self.__dict__)
 
-    @classmethod
-    def string_repr(cls) -> str:
-        return dtype_str_repr(cls)
+    def _string_repr(self) -> str:
+        return dtype_str_repr(self)
 
 
 class NumericType(DataType):
@@ -371,11 +370,11 @@ class Field:
 
     def __repr__(self) -> str:
         class_name = self.__class__.__name__
-        return f"{class_name}({self.name!r}: {self.dtype})"
+        return f"{class_name}({self.name!r}, {self.dtype})"
 
 
 class Struct(NestedType):
-    def __init__(self, fields: Sequence[Field] | Mapping[str, PolarsDataType]):
+    def __init__(self, fields: Sequence[Field] | SchemaDict):
         """
         Struct composite type.
 
@@ -415,7 +414,7 @@ class Struct(NestedType):
         class_name = self.__class__.__name__
         return f"{class_name}({self.fields})"
 
-    def to_schema(self) -> dict[str, PolarsDataType] | None:
+    def to_schema(self) -> SchemaDict | None:
         """Return Struct dtype as a schema dict."""
         return dict(self)
 
@@ -432,6 +431,49 @@ class Unknown(DataType):
     """Type representing Datatype values that could not be determined statically."""
 
 
+TEMPORAL_DTYPES: frozenset[PolarsDataType] = frozenset(
+    [
+        Datetime("ms"),
+        Datetime("us"),
+        Datetime("ns"),
+        Date,
+        Time,
+        Duration("ms"),
+        Duration("us"),
+        Duration("ns"),
+    ]
+)
+DATETIME_DTYPES: frozenset[PolarsDataType] = frozenset(
+    [
+        # TODO: ideally need a mechanism to wildcard timezones here too
+        Datetime("ms"),
+        Datetime("us"),
+        Datetime("ns"),
+    ]
+)
+DURATION_DTYPES: frozenset[PolarsDataType] = frozenset(
+    [
+        Duration("ms"),
+        Duration("us"),
+        Duration("ns"),
+    ]
+)
+INTEGER_DTYPES: frozenset[PolarsDataType] = frozenset(
+    [
+        UInt8,
+        UInt16,
+        UInt32,
+        UInt64,
+        Int8,
+        Int16,
+        Int32,
+        Int64,
+    ]
+)
+FLOAT_DTYPES: frozenset[PolarsDataType] = frozenset([Float32, Float64])
+NUMERIC_DTYPES: frozenset[PolarsDataType] = FLOAT_DTYPES | INTEGER_DTYPES
+
+
 T = TypeVar("T")
 
 
@@ -510,7 +552,7 @@ class _DataTypeMappings:
 
     @property
     @cache
-    def PY_STR_TO_DTYPE(self) -> dict[str, PolarsDataType]:
+    def PY_STR_TO_DTYPE(self) -> SchemaDict:
         return {str(tp.__name__): dtype for tp, dtype in self.PY_TYPE_TO_DTYPE.items()}
 
     @property
@@ -539,22 +581,19 @@ class _DataTypeMappings:
 
     @property
     @cache
-    def NUMPY_CHAR_CODE_TO_DTYPE(self) -> dict[str, PolarsDataType]:
-        # Note: Windows behaves differently from other platforms as C long
-        # is only 32-bit on Windows, while it is 64-bit on other platforms.
-        # See: https://numpy.org/doc/stable/reference/arrays.scalars.html
+    def NUMPY_KIND_AND_ITEMSIZE_TO_DTYPE(self) -> dict[tuple[str, int], PolarsDataType]:
         return {
-            "b": Int8,
-            "h": Int16,
-            "i": Int32,
-            ("q" if sys.platform == "win32" else "l"): Int64,
-            "B": UInt8,
-            "H": UInt16,
-            "I": UInt32,
-            ("Q" if sys.platform == "win32" else "L"): UInt64,
-            "f": Float32,
-            "d": Float64,
-            "?": Boolean,
+            # (np.dtype().kind, np.dtype().itemsize)
+            ("i", 1): Int8,
+            ("i", 2): Int16,
+            ("i", 4): Int32,
+            ("i", 8): Int64,
+            ("u", 1): UInt8,
+            ("u", 2): UInt16,
+            ("u", 4): UInt32,
+            ("u", 8): UInt64,
+            ("f", 4): Float32,
+            ("f", 8): Float64,
         }
 
     @property
@@ -646,11 +685,14 @@ def dtype_to_py_type(dtype: PolarsDataType) -> PythonDataType:
 
 def is_polars_dtype(data_type: Any, include_unknown: bool = False) -> bool:
     """Indicate whether the given input is a Polars dtype, or dtype specialisation."""
-    if data_type == Unknown:
-        # does not represent a realisable dtype, so ignore by default
-        return include_unknown
-    else:
-        return isinstance(data_type, (DataType, DataTypeClass))
+    try:
+        if data_type == Unknown:
+            # does not represent a realisable dtype, so ignore by default
+            return include_unknown
+        else:
+            return isinstance(data_type, (DataType, DataTypeClass))
+    except ValueError:
+        return False
 
 
 @overload
@@ -692,12 +734,11 @@ def py_type_to_dtype(
             data_type = possible_types[0]
     try:
         return DataTypeMappings.PY_TYPE_TO_DTYPE[data_type]
-    except KeyError:  # pragma: no cover
+    except (KeyError, TypeError):  # pragma: no cover
         if not raise_unmatched:
             return None
-        raise NotImplementedError(
-            f"Conversion of Python data type '{data_type}' to Polars data type not"
-            " implemented."
+        raise ValueError(
+            f"Cannot infer dtype from '{data_type}' (type: {type(data_type).__name__})"
         ) from None
 
 
@@ -730,16 +771,24 @@ def dtype_to_arrow_type(dtype: PolarsDataType) -> pa.lib.DataType:
         ) from None
 
 
-def supported_numpy_char_code(dtype: str) -> bool:
-    return dtype in DataTypeMappings.NUMPY_CHAR_CODE_TO_DTYPE
+def supported_numpy_char_code(dtype_char: str) -> bool:
+    dtype = np.dtype(dtype_char)
+    return (
+        dtype.kind,
+        dtype.itemsize,
+    ) in DataTypeMappings.NUMPY_KIND_AND_ITEMSIZE_TO_DTYPE
 
 
-def numpy_char_code_to_dtype(dtype: str) -> PolarsDataType:
+def numpy_char_code_to_dtype(dtype_char: str) -> PolarsDataType:
     """Convert a numpy character dtype to a Polars dtype."""
+    dtype = np.dtype(dtype_char)
+
     try:
-        return DataTypeMappings.NUMPY_CHAR_CODE_TO_DTYPE[dtype]
+        return DataTypeMappings.NUMPY_KIND_AND_ITEMSIZE_TO_DTYPE[
+            (dtype.kind, dtype.itemsize)
+        ]
     except KeyError:  # pragma: no cover
-        raise NotImplementedError(
+        raise ValueError(
             f"Cannot parse numpy data type {dtype} into Polars data type."
         ) from None
 
@@ -758,5 +807,10 @@ def maybe_cast(
 
     py_type = dtype_to_py_type(dtype)
     if not isinstance(el, py_type):
-        el = py_type(el)  # type: ignore[call-arg]
+        try:
+            el = py_type(el)  # type: ignore[call-arg]
+        except Exception:
+            raise ValueError(
+                f"Cannot convert Python type {type(el)} to {dtype}"
+            ) from None
     return el
