@@ -32,6 +32,7 @@ from polars.internals.lazy_functions import (
     arange,
     arg_where,
     argsort_by,
+    coalesce,
     col,
     concat_list,
     count,
@@ -56,6 +57,7 @@ __all__ = [
     "arg_where",
     "argsort_by",
     "BatchedCsvReader",
+    "coalesce",
     "col",
     "concat",
     "concat_list",
