@@ -234,10 +234,7 @@ class ExprListNameSpace:
             return self.concat(pli.Series([other]))
 
         other_list: list[pli.Expr | str | pli.Series]
-        if not isinstance(other, list):
-            other_list = [other]
-        else:
-            other_list = copy.copy(other)  # type: ignore[arg-type]
+        other_list = [other] if not isinstance(other, list) else copy.copy(other)  # type: ignore[arg-type]
 
         other_list.insert(0, pli.wrap_expr(self._pyexpr))
         return pli.concat_list(other_list)
@@ -486,14 +483,39 @@ class ExprListNameSpace:
 
         Examples
         --------
-        >>> s = pl.Series("a", [[1, 2, 3, 4], [10, 2, 1]])
-        >>> s.arr.diff()
-        shape: (2,)
-        Series: 'a' [list[i64]]
-        [
-            [null, 1, ... 1]
-            [null, -8, -1]
-        ]
+        >>> df = pl.DataFrame({"n": [[1, 2, 3, 4], [10, 2, 1]]})
+        >>> df.select(pl.col("n").arr.diff())
+        shape: (2, 1)
+        ┌──────────────────┐
+        │ n                │
+        │ ---              │
+        │ list[i64]        │
+        ╞══════════════════╡
+        │ [null, 1, ... 1] │
+        │ [null, -8, -1]   │
+        └──────────────────┘
+
+        >>> df.select(pl.col("n").arr.diff(n=2))
+        shape: (2, 1)
+        ┌─────────────────────┐
+        │ n                   │
+        │ ---                 │
+        │ list[i64]           │
+        ╞═════════════════════╡
+        │ [null, null, ... 2] │
+        │ [null, null, -9]    │
+        └─────────────────────┘
+
+        >>> df.select(pl.col("n").arr.diff(n=2, null_behavior="drop"))
+        shape: (2, 1)
+        ┌───────────┐
+        │ n         │
+        │ ---       │
+        │ list[i64] │
+        ╞═══════════╡
+        │ [2, 2]    │
+        │ [-9]      │
+        └───────────┘
 
         """
         return pli.wrap_expr(self._pyexpr.lst_diff(n, null_behavior))
@@ -598,6 +620,35 @@ class ExprListNameSpace:
         offset = -pli.expr_to_lit_or_expr(n, str_to_lit=False)
         return self.slice(offset, n)
 
+    def explode(self) -> pli.Expr:
+        """
+        Returns a column with a separate row for every list element.
+
+        Returns
+        -------
+        Exploded column with the datatype of the list elements.
+
+        Examples
+        --------
+        >>> df = pl.DataFrame({"a": [[1, 2, 3], [4, 5, 6]]})
+        >>> df.select(pl.col("a").arr.explode())
+        shape: (6, 1)
+        ┌─────┐
+        │ a   │
+        │ --- │
+        │ i64 │
+        ╞═════╡
+        │ 1   │
+        │ 2   │
+        │ 3   │
+        │ 4   │
+        │ 5   │
+        │ 6   │
+        └─────┘
+
+        """
+        return pli.wrap_expr(self._pyexpr.explode())
+
     def to_struct(
         self,
         n_field_strategy: ToStructStrategy = "first_non_null",
@@ -670,7 +721,7 @@ class ExprListNameSpace:
         Examples
         --------
         >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2]})
-        >>> df.with_column(
+        >>> df.with_columns(
         ...     pl.concat_list(["a", "b"]).arr.eval(pl.element().rank()).alias("rank")
         ... )
         shape: (3, 3)
