@@ -16,13 +16,11 @@ from typing import (
     Iterable,
     Sequence,
     TypeVar,
-    cast,
     overload,
 )
 
 import polars.internals as pli
 from polars.datatypes import (
-    DataType,
     Date,
     Datetime,
     Int64,
@@ -39,6 +37,13 @@ try:
 except ImportError:
     _DOCUMENTING = True
 
+# This code block is due to a typing issue with backports.zoneinfo package:
+# https://github.com/pganssle/zoneinfo/issues/125
+if sys.version_info >= (3, 9):
+    from zoneinfo import ZoneInfo
+elif _ZONEINFO_AVAILABLE:
+    from backports.zoneinfo._zoneinfo import ZoneInfo
+
 if sys.version_info >= (3, 10):
     from typing import ParamSpec, TypeGuard
 else:
@@ -46,11 +51,8 @@ else:
 
 # note: reversed views don't match as instances of MappingView
 if sys.version_info >= (3, 11):
-    _reverse_mapping_views = tuple(
-        type(reversed(cast(Reversible[Any], view)))
-        for view in ({}.keys(), {}.values(), {}.items())
-    )
-
+    _views: list[Reversible[Any]] = [{}.keys(), {}.values(), {}.items()]
+    _reverse_mapping_views = tuple(type(reversed(view)) for view in _views)
 
 if TYPE_CHECKING:
     from polars.internals.type_aliases import SizeUnit, TimeUnit
@@ -261,7 +263,7 @@ EPOCH = datetime(1970, 1, 1).replace(tzinfo=None)
 
 def _to_python_datetime(
     value: int | float,
-    dtype: type[DataType],
+    dtype: PolarsDataType,
     tu: TimeUnit | None = "ns",
     tz: str | None = None,
 ) -> date | datetime:
@@ -290,7 +292,7 @@ def _to_python_datetime(
                     "Install polars[timezone] to handle datetimes with timezones."
                 )
 
-            utc = zoneinfo.ZoneInfo("UTC")
+            utc = ZoneInfo("UTC")
             if tu == "ns":
                 # nanoseconds to seconds
                 dt = datetime.fromtimestamp(0, tz=utc) + timedelta(
@@ -330,7 +332,7 @@ def _parse_fixed_tz_offset(offset: str) -> tzinfo:
 def _localize(dt: datetime, tz: str) -> datetime:
     # zone info installation should already be checked
     try:
-        tzinfo = zoneinfo.ZoneInfo(tz)
+        tzinfo = ZoneInfo(tz)
     except zoneinfo.ZoneInfoNotFoundError:
         # try fixed offset, which is not supported by ZoneInfo
         tzinfo = _parse_fixed_tz_offset(tz)  # type: ignore[assignment]
@@ -398,6 +400,34 @@ def deprecated_alias(**aliases: str) -> Callable[[Callable[P, T]], Callable[P, T
     return deco
 
 
+def redirect(from_to: dict[str, str]) -> Callable[[type[T]], type[T]]:
+    """
+    Class decorator allowing deprecation/transition from one method name to another.
+
+    The parameters must be the same (unless they are being renamed, in
+    which case you can use this in conjunction with @deprecated_alias).
+    """
+
+    def _redirecting_getattr_(obj: T, item: Any) -> Any:
+        if isinstance(item, str) and item in from_to:
+            new_item = from_to[item]
+            warnings.warn(
+                f"`{type(obj).__name__}.{item}` has been renamed; this"
+                f" redirect is temporary, please use `.{new_item}` instead",
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
+            item = new_item
+        return obj.__getattribute__(item)
+
+    def _cls_(cls: type[T]) -> type[T]:
+        # note: __getattr__ is only invoked if item isn't found on the class
+        cls.__getattr__ = _redirecting_getattr_  # type: ignore[attr-defined]
+        return cls
+
+    return _cls_
+
+
 def _rename_kwargs(
     func_name: str, kwargs: dict[str, object], aliases: dict[str, str]
 ) -> None:
