@@ -125,10 +125,10 @@ impl<'a> FromPyObject<'a> for Wrap<BooleanChunked> {
 
 impl<'a> FromPyObject<'a> for Wrap<Utf8Chunked> {
     fn extract(obj: &'a PyAny) -> PyResult<Self> {
-        let (seq, len) = get_pyseq(obj)?;
+        let len = obj.len()?;
         let mut builder = Utf8ChunkedBuilder::new("", len, len * 25);
 
-        for res in seq.iter()? {
+        for res in obj.iter()? {
             let item = res?;
             match item.extract::<&str>() {
                 Ok(val) => builder.append_value(val),
@@ -141,12 +141,12 @@ impl<'a> FromPyObject<'a> for Wrap<Utf8Chunked> {
 
 impl<'a> FromPyObject<'a> for Wrap<BinaryChunked> {
     fn extract(obj: &'a PyAny) -> PyResult<Self> {
-        let (seq, len) = get_pyseq(obj)?;
+        let len = obj.len()?;
         let mut builder = BinaryChunkedBuilder::new("", len, len * 25);
 
-        for res in seq.iter()? {
+        for res in obj.iter()? {
             let item = res?;
-            match item.extract::<&str>() {
+            match item.extract::<&[u8]>() {
                 Ok(val) => builder.append_value(val),
                 Err(_) => builder.append_null(),
             }
@@ -281,6 +281,7 @@ impl ToPyObject for Wrap<DataType> {
             DataType::UInt64 => pl.getattr("UInt64").unwrap().into(),
             DataType::Float32 => pl.getattr("Float32").unwrap().into(),
             DataType::Float64 => pl.getattr("Float64").unwrap().into(),
+            DataType::Decimal128(_) => todo!(),
             DataType::Boolean => pl.getattr("Boolean").unwrap().into(),
             DataType::Utf8 => pl.getattr("Utf8").unwrap().into(),
             DataType::Binary => pl.getattr("Binary").unwrap().into(),
@@ -772,9 +773,10 @@ impl<'a, T: NativeType + FromPyObject<'a>> FromPyObject<'a> for Wrap<Vec<T>> {
 
 pub(crate) fn dicts_to_rows(
     records: &PyAny,
-    infer_schema_len: usize,
+    infer_schema_len: Option<usize>,
     schema_columns: PlIndexSet<String>,
 ) -> PyResult<(Vec<Row>, Vec<String>)> {
+    let infer_schema_len = infer_schema_len.map(|n| std::cmp::max(1, n));
     let (dicts, len) = get_pyseq(records)?;
 
     let key_names = {
@@ -782,7 +784,7 @@ pub(crate) fn dicts_to_rows(
             schema_columns
         } else {
             let mut inferred_keys = PlIndexSet::new();
-            for d in dicts.iter()?.take(infer_schema_len) {
+            for d in dicts.iter()?.take(infer_schema_len.unwrap_or(usize::MAX)) {
                 let d = d?;
                 let d = d.downcast::<PyDict>()?;
                 let keys = d.keys();
