@@ -57,7 +57,8 @@ impl PyDataFrame {
         crate::object::register_object_builder();
 
         let schema =
-            rows_to_schema_supertypes(&rows, infer_schema_length).map_err(PyPolarsErr::from)?;
+            rows_to_schema_supertypes(&rows, infer_schema_length.map(|n| std::cmp::max(1, n)))
+                .map_err(PyPolarsErr::from)?;
         // replace inferred nulls with boolean
         let fields = schema.iter_fields().map(|mut fld| match fld.data_type() {
             DataType::Null => {
@@ -132,6 +133,13 @@ impl PyDataFrame {
     #[staticmethod]
     #[allow(clippy::too_many_arguments)]
     #[cfg(feature = "csv-file")]
+    #[pyo3(signature = (
+        py_f, infer_schema_length, chunk_size, has_header, ignore_errors, n_rows,
+        skip_rows, projection, sep, rechunk, columns, encoding, n_threads, path,
+        overwrite_dtype, overwrite_dtype_slice, low_memory, comment_char, quote_char,
+        null_values, missing_utf8_is_empty_string, parse_dates, skip_rows_after_header,
+        row_count, sample_size, eol_char)
+    )]
     pub fn read_csv(
         py_f: &PyAny,
         infer_schema_length: Option<usize>,
@@ -223,6 +231,7 @@ impl PyDataFrame {
 
     #[staticmethod]
     #[cfg(feature = "parquet")]
+    #[pyo3(signature = (py_f, columns, projection, n_rows, parallel, row_count, low_memory))]
     pub fn read_parquet(
         py_f: PyObject,
         columns: Option<Vec<String>>,
@@ -261,6 +270,7 @@ impl PyDataFrame {
 
     #[staticmethod]
     #[cfg(feature = "ipc")]
+    #[pyo3(signature = (py_f, columns, projection, n_rows, row_count, memory_map))]
     pub fn read_ipc(
         py_f: &PyAny,
         columns: Option<Vec<String>>,
@@ -284,6 +294,7 @@ impl PyDataFrame {
 
     #[staticmethod]
     #[cfg(feature = "avro")]
+    #[pyo3(signature = (py_f, columns, projection, n_rows))]
     pub fn read_avro(
         py_f: PyObject,
         columns: Option<Vec<String>>,
@@ -303,6 +314,7 @@ impl PyDataFrame {
     }
 
     #[cfg(feature = "avro")]
+    #[pyo3(signature = (py_f, compression))]
     pub fn write_avro(
         &mut self,
         py: Python,
@@ -436,12 +448,11 @@ impl PyDataFrame {
         if let Some(schema) = &schema_overwrite {
             schema_columns.extend(schema.0.iter_names().map(|n| n.to_string()))
         }
-        let infer_schema_length = std::cmp::max(infer_schema_length.unwrap_or(50), 1);
         let (rows, names) = dicts_to_rows(dicts, infer_schema_length, schema_columns)?;
 
         let mut pydf = Self::finish_from_rows(
             rows,
-            Some(infer_schema_length),
+            infer_schema_length,
             schema_overwrite.map(|wrap| wrap.0),
         )?;
 
@@ -454,7 +465,7 @@ impl PyDataFrame {
             });
         let length = names.len();
         if names.into_iter().collect::<PlHashSet<_>>().len() != length {
-            let err = PolarsError::SchemaMisMatch("duplicate column names found".into());
+            let err = PolarsError::Duplicate("duplicate column names found".into());
             Err(PyPolarsErr::Polars(err))?;
         }
 
@@ -667,6 +678,7 @@ impl PyDataFrame {
     }
 
     #[cfg(feature = "parquet")]
+    #[pyo3(signature = (py_f, compression, compression_level, statistics, row_group_size))]
     pub fn write_parquet(
         &mut self,
         py: Python,
@@ -1108,6 +1120,7 @@ impl PyDataFrame {
     }
 
     #[cfg(feature = "pivot")]
+    #[allow(clippy::too_many_arguments)]
     pub fn pivot_expr(
         &self,
         values: Vec<String>,
@@ -1116,6 +1129,7 @@ impl PyDataFrame {
         aggregate_expr: PyExpr,
         maintain_order: bool,
         sort_columns: bool,
+        separator: Option<&str>,
     ) -> PyResult<Self> {
         let fun = match maintain_order {
             true => pivot_stable,
@@ -1128,6 +1142,7 @@ impl PyDataFrame {
             columns,
             aggregate_expr.inner,
             sort_columns,
+            separator,
         )
         .map_err(PyPolarsErr::from)?;
         Ok(PyDataFrame::new(df))
@@ -1149,6 +1164,7 @@ impl PyDataFrame {
         self.df.shift(periods).into()
     }
 
+    #[pyo3(signature = (maintain_order, subset, keep))]
     pub fn unique(
         &self,
         py: Python,
@@ -1231,12 +1247,16 @@ impl PyDataFrame {
         Ok(df.into())
     }
 
-    pub fn to_dummies(&self, columns: Option<Vec<String>>) -> PyResult<Self> {
+    pub fn to_dummies(
+        &self,
+        columns: Option<Vec<String>>,
+        separator: Option<&str>,
+    ) -> PyResult<Self> {
         let df = match columns {
             Some(cols) => self
                 .df
-                .columns_to_dummies(cols.iter().map(|x| x as &str).collect()),
-            None => self.df.to_dummies(),
+                .columns_to_dummies(cols.iter().map(|x| x as &str).collect(), separator),
+            None => self.df.to_dummies(separator),
         }
         .map_err(PyPolarsErr::from)?;
         Ok(df.into())
@@ -1247,6 +1267,7 @@ impl PyDataFrame {
         df.into()
     }
 
+    #[pyo3(signature = (lambda, output_type, inference_size))]
     pub fn apply(
         &self,
         lambda: &PyAny,
