@@ -1,8 +1,7 @@
 #![feature(vec_into_raw_parts)]
 #![allow(clippy::nonstandard_macro_braces)] // needed because clippy does not understand proc macro of pyo3
 #![allow(clippy::transmute_undefined_repr)]
-extern crate core;
-extern crate polars;
+extern crate polars as polars_rs;
 
 #[cfg(feature = "build_info")]
 #[macro_use]
@@ -41,11 +40,11 @@ use jemallocator::Jemalloc;
 use lazy::ToExprs;
 #[cfg(any(not(target_os = "linux"), use_mimalloc))]
 use mimalloc::MiMalloc;
-use polars::functions::{diag_concat_df, hor_concat_df};
-use polars::prelude::Null;
 use polars_core::datatypes::{TimeUnit, TimeZone};
 use polars_core::prelude::{DataFrame, IntoSeries, IDX_DTYPE};
 use polars_core::POOL;
+use polars_rs::functions::{diag_concat_df, hor_concat_df};
+use polars_rs::prelude::Null;
 use pyo3::exceptions::PyValueError;
 use pyo3::panic::PanicException;
 use pyo3::prelude::*;
@@ -55,8 +54,8 @@ use pyo3::wrap_pyfunction;
 use crate::conversion::{get_df, get_lf, get_pyseq, get_series, Wrap};
 use crate::dataframe::PyDataFrame;
 use crate::error::{
-    ArrowErrorException, ComputeError, DuplicateError, InvalidOperationError, NoDataError,
-    NotFoundError, PyPolarsErr, SchemaError,
+    ArrowErrorException, ColumnNotFoundError, ComputeError, DuplicateError, InvalidOperationError,
+    NoDataError, PyPolarsErr, SchemaError, SchemaFieldNotFoundError, StructFieldNotFoundError,
 };
 use crate::file::{get_either_file, EitherRustPythonFile};
 use crate::lazy::dataframe::{PyLazyFrame, PyLazyGroupBy};
@@ -144,32 +143,32 @@ fn cumreduce(lambda: PyObject, exprs: Vec<PyExpr>) -> PyExpr {
 
 #[pyfunction]
 fn arange(low: PyExpr, high: PyExpr, step: usize) -> PyExpr {
-    polars::lazy::dsl::arange(low.inner, high.inner, step).into()
+    polars_rs::lazy::dsl::arange(low.inner, high.inner, step).into()
 }
 
 #[pyfunction]
 fn repeat(value: &PyAny, n_times: PyExpr) -> PyResult<PyExpr> {
     if let Ok(true) = value.is_instance_of::<PyBool>() {
         let val = value.extract::<bool>().unwrap();
-        Ok(polars::lazy::dsl::repeat(val, n_times.inner).into())
+        Ok(polars_rs::lazy::dsl::repeat(val, n_times.inner).into())
     } else if let Ok(int) = value.downcast::<PyInt>() {
         let val = int.extract::<i64>().unwrap();
 
         if val > 0 && val < i32::MAX as i64 || val < 0 && val > i32::MIN as i64 {
-            Ok(polars::lazy::dsl::repeat(val as i32, n_times.inner).into())
+            Ok(polars_rs::lazy::dsl::repeat(val as i32, n_times.inner).into())
         } else {
-            Ok(polars::lazy::dsl::repeat(val, n_times.inner).into())
+            Ok(polars_rs::lazy::dsl::repeat(val, n_times.inner).into())
         }
     } else if let Ok(float) = value.downcast::<PyFloat>() {
         let val = float.extract::<f64>().unwrap();
-        Ok(polars::lazy::dsl::repeat(val, n_times.inner).into())
+        Ok(polars_rs::lazy::dsl::repeat(val, n_times.inner).into())
     } else if let Ok(pystr) = value.downcast::<PyString>() {
         let val = pystr
             .to_str()
             .expect("could not transform Python string to Rust Unicode");
-        Ok(polars::lazy::dsl::repeat(val, n_times.inner).into())
+        Ok(polars_rs::lazy::dsl::repeat(val, n_times.inner).into())
     } else if value.is_none() {
-        Ok(polars::lazy::dsl::repeat(Null {}, n_times.inner).into())
+        Ok(polars_rs::lazy::dsl::repeat(Null {}, n_times.inner).into())
     } else {
         Err(PyValueError::new_err(format!(
             "could not convert value {:?} as a Literal",
@@ -180,7 +179,7 @@ fn repeat(value: &PyAny, n_times: PyExpr) -> PyResult<PyExpr> {
 
 #[pyfunction]
 fn pearson_corr(a: dsl::PyExpr, b: dsl::PyExpr, ddof: u8) -> dsl::PyExpr {
-    polars::lazy::dsl::pearson_corr(a.inner, b.inner, ddof).into()
+    polars_rs::lazy::dsl::pearson_corr(a.inner, b.inner, ddof).into()
 }
 
 #[pyfunction]
@@ -192,7 +191,7 @@ fn spearman_rank_corr(
 ) -> dsl::PyExpr {
     #[cfg(feature = "propagate_nans")]
     {
-        polars::lazy::dsl::spearman_rank_corr(a.inner, b.inner, ddof, propagate_nans).into()
+        polars_rs::lazy::dsl::spearman_rank_corr(a.inner, b.inner, ddof, propagate_nans).into()
     }
     #[cfg(not(feature = "propagate_nans"))]
     {
@@ -202,7 +201,7 @@ fn spearman_rank_corr(
 
 #[pyfunction]
 fn cov(a: dsl::PyExpr, b: dsl::PyExpr) -> dsl::PyExpr {
-    polars::lazy::dsl::cov(a.inner, b.inner).into()
+    polars_rs::lazy::dsl::cov(a.inner, b.inner).into()
 }
 
 #[pyfunction]
@@ -210,8 +209,8 @@ fn argsort_by(by: Vec<dsl::PyExpr>, reverse: Vec<bool>) -> dsl::PyExpr {
     let by = by
         .into_iter()
         .map(|e| e.inner)
-        .collect::<Vec<polars::lazy::dsl::Expr>>();
-    polars::lazy::dsl::argsort_by(by, &reverse).into()
+        .collect::<Vec<polars_rs::lazy::dsl::Expr>>();
+    polars_rs::lazy::dsl::argsort_by(by, &reverse).into()
 }
 
 #[pyfunction]
@@ -227,24 +226,24 @@ fn version() -> &'static str {
 
 #[pyfunction]
 fn toggle_string_cache(toggle: bool) {
-    polars::toggle_string_cache(toggle)
+    polars_rs::toggle_string_cache(toggle)
 }
 
 #[pyfunction]
 fn using_string_cache() -> bool {
-    polars::using_string_cache()
+    polars_rs::using_string_cache()
 }
 
 #[pyfunction]
 fn concat_str(s: Vec<dsl::PyExpr>, sep: &str) -> dsl::PyExpr {
     let s = s.into_iter().map(|e| e.inner).collect::<Vec<_>>();
-    polars::lazy::dsl::concat_str(s, sep).into()
+    polars_rs::lazy::dsl::concat_str(s, sep).into()
 }
 
 #[pyfunction]
 fn concat_lst(s: Vec<dsl::PyExpr>) -> dsl::PyExpr {
     let s = s.into_iter().map(|e| e.inner).collect::<Vec<_>>();
-    polars::lazy::dsl::concat_lst(s).into()
+    polars_rs::lazy::dsl::concat_lst(s).into()
 }
 
 #[pyfunction]
@@ -272,7 +271,7 @@ fn py_datetime(
         microsecond,
     };
 
-    polars::lazy::dsl::datetime(args).into()
+    polars_rs::lazy::dsl::datetime(args).into()
 }
 
 #[allow(clippy::too_many_arguments)]
@@ -298,7 +297,7 @@ fn py_duration(
         weeks: weeks.map(|e| e.inner),
     };
 
-    polars::lazy::dsl::duration(args).into()
+    polars_rs::lazy::dsl::duration(args).into()
 }
 
 #[pyfunction]
@@ -354,7 +353,7 @@ fn concat_lf(lfs: &PyAny, rechunk: bool, parallel: bool) -> PyResult<PyLazyFrame
         lfs.push(lf);
     }
 
-    let lf = polars::lazy::dsl::concat(lfs, rechunk, parallel).map_err(PyPolarsErr::from)?;
+    let lf = polars_rs::lazy::dsl::concat(lfs, rechunk, parallel).map_err(PyPolarsErr::from)?;
     Ok(lf.into())
 }
 
@@ -386,7 +385,7 @@ fn py_diag_concat_lf(lfs: &PyAny, rechunk: bool, parallel: bool) -> PyResult<PyL
         })
         .collect::<PyResult<Vec<_>>>()?;
 
-    let lf = polars::lazy::dsl::functions::diag_concat_lf(lfs, rechunk, parallel)
+    let lf = polars_rs::lazy::dsl::functions::diag_concat_lf(lfs, rechunk, parallel)
         .map_err(PyPolarsErr::from)?;
     Ok(lf.into())
 }
@@ -481,6 +480,7 @@ fn collect_all(lfs: Vec<PyLazyFrame>, py: Python) -> PyResult<Vec<PyDataFrame>>
 }
 
 #[pyfunction]
+#[pyo3(signature = (pyexpr, lambda, output_type, apply_groups, returns_scalar))]
 pub fn map_mul(
     py: Python,
     pyexpr: Vec<PyExpr>,
@@ -508,8 +508,8 @@ fn py_date_range(
     name: &str,
     tu: Wrap<TimeUnit>,
     tz: Option<TimeZone>,
-) -> PySeries {
-    polars::time::date_range_impl(
+) -> PyResult<PySeries> {
+    let date_range = polars_rs::time::date_range_impl(
         name,
         start,
         stop,
@@ -518,8 +518,8 @@ fn py_date_range(
         tu.0,
         tz.as_ref(),
     )
-    .into_series()
-    .into()
+    .map_err(PyPolarsErr::from)?;
+    Ok(date_range.into_series().into())
 }
 
 #[pyfunction]
@@ -534,37 +534,37 @@ fn py_date_range_lazy(
     let start = start.inner;
     let end = end.inner;
     let every = Duration::parse(every);
-    polars::lazy::dsl::functions::date_range(name, start, end, every, closed.0, tz).into()
+    polars_rs::lazy::dsl::functions::date_range(name, start, end, every, closed.0, tz).into()
 }
 
 #[pyfunction]
 fn min_exprs(exprs: Vec<PyExpr>) -> PyExpr {
     let exprs = exprs.to_exprs();
-    polars::lazy::dsl::min_exprs(exprs).into()
+    polars_rs::lazy::dsl::min_exprs(exprs).into()
 }
 
 #[pyfunction]
 fn max_exprs(exprs: Vec<PyExpr>) -> PyExpr {
     let exprs = exprs.to_exprs();
-    polars::lazy::dsl::max_exprs(exprs).into()
+    polars_rs::lazy::dsl::max_exprs(exprs).into()
 }
 
 #[pyfunction]
 fn coalesce_exprs(exprs: Vec<PyExpr>) -> PyExpr {
     let exprs = exprs.to_exprs();
-    polars::lazy::dsl::coalesce(&exprs).into()
+    polars_rs::lazy::dsl::coalesce(&exprs).into()
 }
 
 #[pyfunction]
 fn sum_exprs(exprs: Vec<PyExpr>) -> PyExpr {
     let exprs = exprs.to_exprs();
-    polars::lazy::dsl::sum_exprs(exprs).into()
+    polars_rs::lazy::dsl::sum_exprs(exprs).into()
 }
 
 #[pyfunction]
 fn as_struct(exprs: Vec<PyExpr>) -> PyExpr {
     let exprs = exprs.to_exprs();
-    polars::lazy::dsl::as_struct(&exprs).into()
+    polars_rs::lazy::dsl::as_struct(&exprs).into()
 }
 
 #[pyfunction]
@@ -574,7 +574,7 @@ fn pool_size() -> usize {
 
 #[pyfunction]
 fn arg_where(condition: PyExpr) -> PyExpr {
-    polars::lazy::dsl::arg_where(condition.inner).into()
+    polars_rs::lazy::dsl::arg_where(condition.inner).into()
 }
 
 #[pyfunction]
@@ -600,25 +600,35 @@ fn set_float_fmt(fmt: &str) -> PyResult<()> {
 
 #[pymodule]
 fn polars(py: Python, m: &PyModule) -> PyResult<()> {
-    m.add("NotFoundError", py.get_type::<NotFoundError>())
-        .unwrap();
-    m.add("NoDataError", py.get_type::<NoDataError>()).unwrap();
-    m.add("ComputeError", py.get_type::<ComputeError>())
-        .unwrap();
-    m.add("ShapeError", py.get_type::<crate::error::ShapeError>())
-        .unwrap();
-    m.add("SchemaError", py.get_type::<SchemaError>()).unwrap();
     m.add("ArrowError", py.get_type::<ArrowErrorException>())
         .unwrap();
-    m.add("DuplicateError", py.get_type::<DuplicateError>())
+    m.add("ColumnNotFoundError", py.get_type::<ColumnNotFoundError>())
         .unwrap();
-    m.add("PanicException", py.get_type::<PanicException>())
+    m.add("ComputeError", py.get_type::<ComputeError>())
+        .unwrap();
+    m.add("DuplicateError", py.get_type::<DuplicateError>())
         .unwrap();
     m.add(
         "InvalidOperationError",
         py.get_type::<InvalidOperationError>(),
     )
     .unwrap();
+    m.add("NoDataError", py.get_type::<NoDataError>()).unwrap();
+    m.add("PanicException", py.get_type::<PanicException>())
+        .unwrap();
+    m.add("SchemaError", py.get_type::<SchemaError>()).unwrap();
+    m.add(
+        "SchemaFieldNotFoundError",
+        py.get_type::<SchemaFieldNotFoundError>(),
+    )
+    .unwrap();
+    m.add("ShapeError", py.get_type::<crate::error::ShapeError>())
+        .unwrap();
+    m.add(
+        "StructFieldNotFoundError",
+        py.get_type::<StructFieldNotFoundError>(),
+    )
+    .unwrap();
 
     #[cfg(feature = "build_info")]
     m.add(
