@@ -238,6 +238,13 @@ impl PySeries {
         PySeries::new(s)
     }
 
+    #[staticmethod]
+    pub fn new_binary(name: &str, val: Wrap<BinaryChunked>, _strict: bool) -> Self {
+        let mut s = val.0.into_series();
+        s.rename(name);
+        PySeries::new(s)
+    }
+
     #[staticmethod]
     pub fn new_object(name: &str, val: Vec<ObjectValue>, _strict: bool) -> Self {
         #[cfg(feature = "object")]
@@ -326,35 +333,6 @@ impl PySeries {
         py_seq_to_list(name, seq, &dtype.0).map(|s| s.into())
     }
 
-    /// Should only be called for Series with null types.
-    /// This will cast to floats so that `None = np.nan`
-    pub fn to_numpy(&self, py: Python) -> PyObject {
-        let s = &self.series;
-        if s.bit_repr_is_large() {
-            let s = s.cast(&DataType::Float64).unwrap();
-            let ca = s.f64().unwrap();
-            let np_arr = PyArray1::from_iter(
-                py,
-                ca.into_iter().map(|opt_v| match opt_v {
-                    Some(v) => v,
-                    None => f64::NAN,
-                }),
-            );
-            np_arr.into_py(py)
-        } else {
-            let s = s.cast(&DataType::Float32).unwrap();
-            let ca = s.f32().unwrap();
-            let np_arr = PyArray1::from_iter(
-                py,
-                ca.into_iter().map(|opt_v| match opt_v {
-                    Some(v) => v,
-                    None => f32::NAN,
-                }),
-            );
-            np_arr.into_py(py)
-        }
-    }
-
     pub fn estimated_size(&self) -> usize {
         self.series.estimated_size()
     }
@@ -666,6 +644,7 @@ impl PySeries {
                     DataType::Int64 => PyList::new(py, series.i64().unwrap()),
                     DataType::Float32 => PyList::new(py, series.f32().unwrap()),
                     DataType::Float64 => PyList::new(py, series.f64().unwrap()),
+                    DataType::Decimal128(_) => todo!(),
                     DataType::Categorical(_) => {
                         PyList::new(py, series.categorical().unwrap().iter_str())
                     }
@@ -784,6 +763,7 @@ impl PySeries {
         PySeries::new(self.series.clone())
     }
 
+    #[pyo3(signature = (lambda, output_type, skip_nulls))]
     pub fn apply_lambda(
         &self,
         lambda: &PyAny,
@@ -1022,8 +1002,8 @@ impl PySeries {
         Ok(PySeries::new(s))
     }
 
-    pub fn to_dummies(&self) -> PyResult<PyDataFrame> {
-        let df = self.series.to_dummies().map_err(PyPolarsErr::from)?;
+    pub fn to_dummies(&self, sep: Option<&str>) -> PyResult<PyDataFrame> {
+        let df = self.series.to_dummies(sep).map_err(PyPolarsErr::from)?;
         Ok(df.into())
     }
 
