@@ -1,14 +1,23 @@
 from __future__ import annotations
 
+from pathlib import Path
+
+import pytest
+
 import polars as pl
 
 
-def test_row_count(foods_ipc: str) -> None:
-    df = pl.read_ipc(foods_ipc, row_count_name="row_count", use_pyarrow=False)
+@pytest.fixture()
+def foods_ipc_path(io_files_path: Path) -> Path:
+    return io_files_path / "foods1.ipc"
+
+
+def test_row_count(foods_ipc_path: Path) -> None:
+    df = pl.read_ipc(foods_ipc_path, row_count_name="row_count", use_pyarrow=False)
     assert df["row_count"].to_list() == list(range(27))
 
     df = (
-        pl.scan_ipc(foods_ipc, row_count_name="row_count")
+        pl.scan_ipc(foods_ipc_path, row_count_name="row_count")
         .filter(pl.col("category") == pl.lit("vegetables"))
         .collect()
     )
@@ -16,7 +25,7 @@ def test_row_count(foods_ipc: str) -> None:
     assert df["row_count"].to_list() == [0, 6, 11, 13, 14, 20, 25]
 
     df = (
-        pl.scan_ipc(foods_ipc, row_count_name="row_count")
+        pl.scan_ipc(foods_ipc_path, row_count_name="row_count")
         .with_row_count("foo", 10)
         .filter(pl.col("category") == pl.lit("vegetables"))
         .collect()
@@ -25,15 +34,15 @@ def test_row_count(foods_ipc: str) -> None:
     assert df["foo"].to_list() == [10, 16, 21, 23, 24, 30, 35]
 
 
-def test_is_in_type_coercion(foods_ipc: str) -> None:
+def test_is_in_type_coercion(foods_ipc_path: Path) -> None:
     out = (
-        pl.scan_ipc(foods_ipc)
+        pl.scan_ipc(foods_ipc_path)
         .filter(pl.col("category").is_in(("vegetables", "ice cream")))
         .collect()
     )
     assert out.shape == (7, 4)
     out = (
-        pl.scan_ipc(foods_ipc)
+        pl.scan_ipc(foods_ipc_path)
         .select(pl.col("category").alias("cat"))
         .filter(pl.col("cat").is_in(["vegetables"]))
         .collect()
@@ -41,7 +50,9 @@ def test_is_in_type_coercion(foods_ipc: str) -> None:
     assert out.shape == (7, 1)
 
 
-def test_row_count_schema(foods_ipc: str) -> None:
+def test_row_count_schema(foods_ipc_path: Path) -> None:
     assert (
-        pl.scan_ipc(foods_ipc, row_count_name="id").select(["id", "category"]).collect()
+        pl.scan_ipc(foods_ipc_path, row_count_name="id")
+        .select(["id", "category"])
+        .collect()
     ).dtypes == [pl.UInt32, pl.Utf8]
