@@ -16,7 +16,7 @@ from polars.datatypes import (
     NUMERIC_DTYPES,
     TEMPORAL_DTYPES,
 )
-from polars.testing import assert_series_equal
+from polars.testing import assert_frame_equal, assert_series_equal
 
 
 def test_horizontal_agg(fruits_cars: pl.DataFrame) -> None:
@@ -60,8 +60,8 @@ def test_filter_where() -> None:
         pl.col("b").filter(pl.col("b") > 4).alias("c")
     )
     expected = pl.DataFrame({"a": [1, 2, 3], "c": [[7], [5, 8], [6, 9]]})
-    assert result_where.frame_equal(expected)
-    assert result_filter.frame_equal(expected)
+    assert_frame_equal(result_where, expected)
+    assert_frame_equal(result_filter, expected)
 
 
 def test_min_nulls_consistency() -> None:
@@ -100,7 +100,7 @@ def test_shuffle() -> None:
     result1 = pl.select(pl.lit(s).shuffle()).to_series()
     random.seed(1)
     result2 = pl.select(pl.lit(s).shuffle()).to_series()
-    assert result1.series_equal(result2)
+    assert_series_equal(result1, result2)
 
 
 def test_sample() -> None:
@@ -124,7 +124,7 @@ def test_sample() -> None:
     result1 = pl.select(pl.lit(a).sample(n=10)).to_series()
     random.seed(1)
     result2 = pl.select(pl.lit(a).sample(n=10)).to_series()
-    assert result1.series_equal(result2)
+    assert_series_equal(result1, result2)
 
 
 def test_map_alias() -> None:
@@ -132,7 +132,7 @@ def test_map_alias() -> None:
         (pl.col("foo") * 2).map_alias(lambda name: f"{name}{name}")
     )
     expected = pl.DataFrame({"foofoo": [2, 4, 6]})
-    assert out.frame_equal(expected)
+    assert_frame_equal(out, expected)
 
 
 def test_unique_stable() -> None:
@@ -141,91 +141,6 @@ def test_unique_stable() -> None:
     assert_series_equal(s.unique(maintain_order=True), expected)
 
 
-def test_wildcard_expansion() -> None:
-    # one function requires wildcard expansion the other need
-    # this tests the nested behavior
-    # see: #2867
-
-    df = pl.DataFrame({"a": ["x", "Y", "z"], "b": ["S", "o", "S"]})
-    assert df.select(
-        pl.concat_str(pl.all()).str.to_lowercase()
-    ).to_series().to_list() == ["xs", "yo", "zs"]
-
-
-def test_split() -> None:
-    df = pl.DataFrame({"x": ["a_a", None, "b", "c_c_c"]})
-    out = df.select([pl.col("x").str.split("_")])
-
-    expected = pl.DataFrame(
-        [
-            {"x": ["a", "a"]},
-            {"x": None},
-            {"x": ["b"]},
-            {"x": ["c", "c", "c"]},
-        ]
-    )
-
-    assert out.frame_equal(expected)
-    assert df["x"].str.split("_").to_frame().frame_equal(expected)
-
-    out = df.select([pl.col("x").str.split("_", inclusive=True)])
-
-    expected = pl.DataFrame(
-        [
-            {"x": ["a_", "a"]},
-            {"x": None},
-            {"x": ["b"]},
-            {"x": ["c_", "c_", "c"]},
-        ]
-    )
-
-    assert out.frame_equal(expected)
-    assert df["x"].str.split("_", inclusive=True).to_frame().frame_equal(expected)
-
-
-def test_split_exact() -> None:
-    df = pl.DataFrame({"x": ["a_a", None, "b", "c_c"]})
-    out = df.select([pl.col("x").str.split_exact("_", 2, inclusive=False)]).unnest("x")
-
-    expected = pl.DataFrame(
-        {
-            "field_0": ["a", None, "b", "c"],
-            "field_1": ["a", None, None, "c"],
-            "field_2": pl.Series([None, None, None, None], dtype=pl.Utf8),
-        }
-    )
-
-    assert out.frame_equal(expected)
-    assert (
-        df["x"]
-        .str.split_exact("_", 2, inclusive=False)
-        .to_frame()
-        .unnest("x")
-        .frame_equal(expected)
-    )
-
-    out = df.select([pl.col("x").str.split_exact("_", 1, inclusive=True)]).unnest("x")
-
-    expected = pl.DataFrame(
-        {"field_0": ["a_", None, "b", "c_"], "field_1": ["a", None, None, "c"]}
-    )
-    assert out.frame_equal(expected)
-    assert df["x"].str.split_exact("_", 1).dtype == pl.Struct
-    assert df["x"].str.split_exact("_", 1, inclusive=False).dtype == pl.Struct
-
-
-def test_splitn() -> None:
-    df = pl.DataFrame({"x": ["a_a", None, "b", "c_c_c"]})
-    out = df.select([pl.col("x").str.splitn("_", 2)]).unnest("x")
-
-    expected = pl.DataFrame(
-        {"field_0": ["a", None, "b", "c"], "field_1": ["a", None, None, "c_c"]}
-    )
-
-    assert out.frame_equal(expected)
-    assert df["x"].str.splitn("_", 2).to_frame().unnest("x").frame_equal(expected)
-
-
 def test_unique_and_drop_stability() -> None:
     # see: 2898
     # the original cause was that we wrote:
@@ -249,16 +164,13 @@ def test_entropy() -> None:
             "id": [1, 2, 1, 4, 5, 4, 6],
         }
     )
-
-    assert (
-        df.groupby("group", maintain_order=True).agg(
-            pl.col("id").entropy(normalize=True)
-        )
-    ).frame_equal(
-        pl.DataFrame(
-            {"group": ["A", "B"], "id": [1.0397207708399179, 1.371381017771811]}
-        )
+    result = df.groupby("group", maintain_order=True).agg(
+        pl.col("id").entropy(normalize=True)
     )
+    expected = pl.DataFrame(
+        {"group": ["A", "B"], "id": [1.0397207708399179, 1.371381017771811]}
+    )
+    assert_frame_equal(result, expected)
 
 
 def test_dot_in_groupby() -> None:
@@ -270,11 +182,11 @@ def test_dot_in_groupby() -> None:
         }
     )
 
-    assert (
-        df.groupby("group", maintain_order=True)
-        .agg(pl.col("x").dot("y").alias("dot"))
-        .frame_equal(pl.DataFrame({"group": ["a", "b"], "dot": [6, 15]}))
+    result = df.groupby("group", maintain_order=True).agg(
+        pl.col("x").dot("y").alias("dot")
     )
+    expected = pl.DataFrame({"group": ["a", "b"], "dot": [6, 15]})
+    assert_frame_equal(result, expected)
 
 
 def test_dtype_col_selection() -> None:
@@ -303,7 +215,7 @@ def test_dtype_col_selection() -> None:
             "n": pl.UInt64,
         },
     )
-    assert set(df.select(pl.col(INTEGER_DTYPES)).columns) == {
+    assert df.select(pl.col(INTEGER_DTYPES)).columns == [
         "e",
         "f",
         "g",
@@ -312,9 +224,9 @@ def test_dtype_col_selection() -> None:
         "l",
         "m",
         "n",
-    }
-    assert set(df.select(pl.col(FLOAT_DTYPES)).columns) == {"i", "j"}
-    assert set(df.select(pl.col(NUMERIC_DTYPES)).columns) == {
+    ]
+    assert df.select(pl.col(FLOAT_DTYPES)).columns == ["i", "j"]
+    assert df.select(pl.col(NUMERIC_DTYPES)).columns == [
         "e",
         "f",
         "g",
@@ -325,8 +237,8 @@ def test_dtype_col_selection() -> None:
         "l",
         "m",
         "n",
-    }
-    assert set(df.select(pl.col(TEMPORAL_DTYPES)).columns) == {
+    ]
+    assert df.select(pl.col(TEMPORAL_DTYPES)).columns == [
         "a1",
         "a2",
         "a3",
@@ -337,19 +249,19 @@ def test_dtype_col_selection() -> None:
         "d2",
         "d3",
         "d4",
-    }
-    assert set(df.select(pl.col(DATETIME_DTYPES)).columns) == {
+    ]
+    assert df.select(pl.col(DATETIME_DTYPES)).columns == [
         "a1",
         "a2",
         "a3",
         "a4",
-    }
-    assert set(df.select(pl.col(DURATION_DTYPES)).columns) == {
+    ]
+    assert df.select(pl.col(DURATION_DTYPES)).columns == [
         "d1",
         "d2",
         "d3",
         "d4",
-    }
+    ]
 
 
 def test_list_eval_expression() -> None:
@@ -482,7 +394,7 @@ def test_rank_so_4109() -> None:
 def test_unique_empty() -> None:
     for dt in [pl.Utf8, pl.Boolean, pl.Int32, pl.UInt32]:
         s = pl.Series([], dtype=dt)
-        assert s.unique().series_equal(s)
+        assert_series_equal(s.unique(), s)
 
 
 @typing.no_type_check
@@ -557,3 +469,54 @@ def test_ewm_with_multiple_chunks() -> None:
         ]
     )
     assert ewm_std.null_count().sum(axis=1)[0] == 4
+
+
+def test_map_dict() -> None:
+    country_code_dict = {
+        "CA": "Canada",
+        "DE": "Germany",
+        "FR": "France",
+        None: "Not specified",
+    }
+    df = pl.DataFrame(
+        {
+            "country_code": ["FR", None, "ES", "DE"],
+        }
+    ).with_row_count()
+
+    assert (
+        df.with_columns(
+            pl.col("country_code")
+            .map_dict(country_code_dict, default=pl.col("country_code"))
+            .alias("remapped")
+        )
+    ).to_dict(False) == {
+        "row_nr": [0, 1, 2, 3],
+        "country_code": ["FR", None, "ES", "DE"],
+        "remapped": ["France", "Not specified", "ES", "Germany"],
+    }
+
+    assert (
+        df.with_columns(
+            pl.col("country_code").map_dict(country_code_dict).alias("remapped")
+        )
+    ).to_dict(False) == {
+        "row_nr": [0, 1, 2, 3],
+        "country_code": ["FR", None, "ES", "DE"],
+        "remapped": ["France", "Not specified", None, "Germany"],
+    }
+
+    assert (
+        df.with_columns(
+            pl.struct(pl.col(["country_code", "row_nr"]))  # type: ignore[union-attr]
+            .map_dict(
+                country_code_dict,
+                default=pl.col("row_nr").cast(pl.Utf8),
+            )
+            .alias("remapped")
+        )
+    ).to_dict(False) == {
+        "row_nr": [0, 1, 2, 3],
+        "country_code": ["FR", None, "ES", "DE"],
+        "remapped": ["France", "Not specified", "2", "Germany"],
+    }
