@@ -66,7 +66,7 @@ def test_groupby() -> None:
 
     # Invalid input: `by` not specified as a sequence
     with pytest.raises(TypeError):
-        df.groupby("a", "b")  # type: ignore[arg-type]
+        df.groupby("a", "b")  # type: ignore[arg-type, misc]
 
 
 def test_groupby_iteration() -> None:
@@ -77,23 +77,30 @@ def test_groupby_iteration() -> None:
             "baz": [6, 5, 4, 3, 2, 1],
         }
     )
-    expected_shapes = [(2, 3), (3, 3), (1, 3)]
+    expected_names = ["a", "b", "c"]
     expected_rows = [
         [("a", 1, 6), ("a", 3, 4)],
         [("b", 2, 5), ("b", 4, 3), ("b", 5, 2)],
         [("c", 6, 1)],
     ]
-    for i, group in enumerate(df.groupby("foo", maintain_order=True)):
-        assert group.shape == expected_shapes[i]
-        assert group.rows() == expected_rows[i]
+    for i, (group, data) in enumerate(df.groupby("foo", maintain_order=True)):
+        assert group == expected_names[i]
+        assert data.rows() == expected_rows[i]
 
     # Grouped by ALL columns should give groups of a single row
     result = list(df.groupby(["foo", "bar", "baz"]))
     assert len(result) == 6
 
     # Iterating over groups should also work when grouping by expressions
-    result = list(df.groupby(["foo", pl.col("bar") * pl.col("baz")]))
-    assert len(result) == 5
+    result2 = list(df.groupby(["foo", pl.col("bar") * pl.col("baz")]))
+    assert len(result2) == 5
+
+    # Single column, alias in groupby
+    df = pl.DataFrame({"foo": [1, 2, 3, 4, 5, 6]})
+    gb = df.groupby((pl.col("foo") // 2).alias("bar"), maintain_order=True)
+    result3 = [(group, df.rows()) for group, df in gb]
+    expected3 = [(0, [(1,)]), (1, [(2,), (3,)]), (2, [(4,), (5,)]), (3, [(6,)])]
+    assert result3 == expected3
 
 
 def bad_agg_parameters() -> list[Any]:
@@ -246,7 +253,7 @@ def test_groupby_rolling_negative_offset_3914() -> None:
         }
     )
 
-    assert df.groupby_rolling(index_column="ints", period="2i", offset="-5i",).agg(
+    assert df.groupby_rolling(index_column="ints", period="2i", offset="-5i").agg(
         [pl.col("ints").alias("matches")]
     )["matches"].to_list() == [
         [],
@@ -401,7 +408,7 @@ def test_groupby_all_masked_out() -> None:
     )
     parts = df.partition_by("val")
     assert len(parts) == 1
-    assert parts[0].frame_equal(df)
+    assert_frame_equal(parts[0], df)
 
 
 def test_groupby_min_max_string_type() -> None:
@@ -484,3 +491,17 @@ def test_groupby_dynamic_iter() -> None:
         ((2, datetime(2020, 1, 1, 11)), (1, 3)),
     ]
     assert result2 == expected2
+
+
+@pytest.mark.slow()
+@pytest.mark.parametrize("dtype", [pl.Int32, pl.UInt32])
+def test_overflow_mean_partitioned_groupby_5194(dtype: pl.PolarsDataType) -> None:
+    df = pl.DataFrame(
+        [
+            pl.Series("data", [10_00_00_00] * 100_000, dtype=dtype),
+            pl.Series("group", [1, 2] * 50_000, dtype=dtype),
+        ]
+    )
+    assert df.groupby("group").agg(pl.col("data").mean()).sort(by="group").to_dict(
+        False
+    ) == {"group": [1, 2], "data": [10000000.0, 10000000.0]}
