@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import typing
 from datetime import datetime
 from typing import Any, cast, no_type_check
 
@@ -10,6 +11,7 @@ import pytest
 
 import polars as pl
 from polars.datatypes import dtype_to_py_type
+from polars.testing import assert_series_equal
 
 
 def test_df_from_numpy() -> None:
@@ -26,6 +28,8 @@ def test_df_from_numpy() -> None:
             "float16": np.array([21.7, 21.8, 21], dtype=np.float16),
             "float32": np.array([21.7, 21.8, 21], dtype=np.float32),
             "float64": np.array([21.7, 21.8, 21], dtype=np.float64),
+            "intc": np.array([1, 3, 2], dtype=np.intc),
+            "uintc": np.array([1, 3, 2], dtype=np.uintc),
             "str": np.array(["string1", "string2", "string3"], dtype=np.str_),
             "bytes": np.array(
                 ["byte_string1", "byte_string2", "byte_string3"], dtype=np.bytes_
@@ -45,8 +49,10 @@ def test_df_from_numpy() -> None:
         pl.datatypes.Float32,
         pl.datatypes.Float32,
         pl.datatypes.Float64,
+        pl.datatypes.Int32,
+        pl.datatypes.UInt32,
         pl.datatypes.Utf8,
-        pl.datatypes.Object,
+        pl.datatypes.Binary,
     ]
     assert out == df.dtypes
 
@@ -82,6 +88,10 @@ def test_to_numpy() -> None:
     test_series_to_numpy("float64", [21.7, 21.8, 21], pl.Float64, np.float64)
 
     test_series_to_numpy("str", ["string1", "string2", "string3"], pl.Utf8, np.object_)
+    # without pyarrow
+    arr = pl.Series(["a", "b", None]).to_numpy(use_pyarrow=False)
+    assert arr.dtype == np.dtype("O")
+    assert list(arr) == ["a", "b", None]
 
 
 def test_from_pandas() -> None:
@@ -119,8 +129,14 @@ def test_from_pandas() -> None:
         (False, False, 3, 3.0, 3.0, 3.0, "ham", "ham", "ham"),
     ]
 
+    # partial dtype overrides from pandas
+    overrides = {"int": pl.Int8, "int_nulls": pl.Int32, "floats": pl.Float32}
+    out = pl.from_pandas(df, schema_overrides=overrides)
+    for col, dtype in overrides.items():
+        assert out.schema[col] == dtype
 
-def test_from_pandas_nan_to_none() -> None:
+
+def test_from_pandas_nan_to_null() -> None:
     df = pd.DataFrame(
         {
             "bools_nulls": [None, True, False],
@@ -131,13 +147,13 @@ def test_from_pandas_nan_to_none() -> None:
         }
     )
     out_true = pl.from_pandas(df)
-    out_false = pl.from_pandas(df, nan_to_none=False)
+    out_false = pl.from_pandas(df, nan_to_null=False)
     assert all(val is None for val in out_true["nulls"])
     assert all(np.isnan(val) for val in out_false["nulls"][1:])
 
     df = pd.Series([2, np.nan, None], name="pd")  # type: ignore[assignment]
     out_true = pl.from_pandas(df)
-    out_false = pl.from_pandas(df, nan_to_none=False)
+    out_false = pl.from_pandas(df, nan_to_null=False)
     assert [val is None for val in out_true]
     assert [np.isnan(val) for val in out_false[1:]]
 
@@ -189,7 +205,7 @@ def test_arrow_dict_to_polars() -> None:
         values=["AAA", "BBB", "CCC", "DDD", "BBB", "AAA", "CCC", "DDD", "DDD", "CCC"],
     )
 
-    assert s.series_equal(pl.Series("pa_dict", pa_dict))
+    assert_series_equal(s, pl.Series("pa_dict", pa_dict))
 
 
 def test_arrow_list_chunked_array() -> None:
@@ -238,7 +254,7 @@ def test_from_dict() -> None:
     df = pl.from_dict(data)
     assert df.shape == (2, 2)
     for s1, s2 in zip(list(df), [pl.Series("a", [1, 2]), pl.Series("b", [3, 4])]):
-        assert s1.series_equal(s2)
+        assert_series_equal(s1, s2)
 
 
 def test_from_dict_struct() -> None:
@@ -264,7 +280,7 @@ def test_from_dicts() -> None:
 def test_from_dict_no_inference() -> None:
     schema = {"a": pl.Utf8}
     data = [{"a": "aa"}]
-    pl.from_dicts(data, schema=schema, infer_schema_length=0)
+    pl.from_dicts(data, schema_overrides=schema, infer_schema_length=0)
 
 
 def test_from_dicts_schema_override() -> None:
@@ -290,7 +306,7 @@ def test_from_dicts_schema_override() -> None:
     for n_infer in (0, 3, 5, 8, 10, 100):
         df = pl.DataFrame(
             data=(data1 + data2),
-            columns=schema,  # type: ignore[arg-type]
+            schema=schema,  # type: ignore[arg-type]
             infer_schema_length=n_infer,
         )
         assert df.schema == schema
@@ -326,16 +342,22 @@ def test_from_dicts_struct() -> None:
 
 def test_from_records() -> None:
     data = [[1, 2, 3], [4, 5, 6]]
-    df = pl.from_records(data, columns=["a", "b"])
+    df = pl.from_records(data, schema=["a", "b"])
     assert df.shape == (3, 2)
     assert df.rows() == [(1, 4), (2, 5), (3, 6)]
 
 
 def test_from_numpy() -> None:
     data = np.array([[1, 2, 3], [4, 5, 6]])
-    df = pl.from_numpy(data, columns=["a", "b"], orient="col")
+    df = pl.from_numpy(
+        data,
+        schema=["a", "b"],
+        orient="col",
+        schema_overrides={"a": pl.UInt32, "b": pl.UInt32},
+    )
     assert df.shape == (3, 2)
     assert df.rows() == [(1, 4), (2, 5), (3, 6)]
+    assert df.schema == {"a": pl.UInt32, "b": pl.UInt32}
 
 
 def test_from_arrow() -> None:
@@ -348,6 +370,12 @@ def test_from_arrow() -> None:
     with pytest.raises(ValueError):
         _ = pl.from_arrow([1, 2])
 
+    df = pl.from_arrow(
+        data, schema=["a", "b"], schema_overrides={"a": pl.UInt32, "b": pl.UInt64}
+    )
+    assert df.rows() == [(1, 4), (2, 5), (3, 6)]  # type: ignore[union-attr]
+    assert df.schema == {"a": pl.UInt32, "b": pl.UInt64}  # type: ignore[union-attr]
+
 
 def test_from_pandas_dataframe() -> None:
     pd_df = pd.DataFrame([[1, 2, 3], [4, 5, 6]], columns=["a", "b", "c"])
@@ -375,7 +403,7 @@ def test_from_optional_not_available() -> None:
 
     np = _LazyModule("numpy", module_available=False)
     with pytest.raises(ImportError, match=r"np\.array requires 'numpy'"):
-        pl.from_numpy(np.array([[1, 2], [3, 4]]), columns=["a", "b"])
+        pl.from_numpy(np.array([[1, 2], [3, 4]]), schema=["a", "b"])
 
     pa = _LazyModule("pyarrow", module_available=False)
     with pytest.raises(ImportError, match=r"pa\.table requires 'pyarrow'"):
@@ -418,8 +446,53 @@ def test_no_rechunk() -> None:
 def test_cat_to_pandas() -> None:
     df = pl.DataFrame({"a": ["best", "test"]})
     df = df.with_columns(pl.all().cast(pl.Categorical))
-    out = df.to_pandas()
-    assert "category" in str(out["a"].dtype)
+    pd_out = df.to_pandas()
+    assert "category" in str(pd_out["a"].dtype)
+
+    try:
+        pd_pa_out = df.to_pandas(use_pyarrow_extension_array=True)
+        assert pd_pa_out["a"].dtype.type == pa.DictionaryType
+    except ModuleNotFoundError:
+        # Skip test if Pandas 1.5.x is not installed.
+        pass
+
+
+def test_to_pandas() -> None:
+    df = pl.DataFrame(
+        {"a": [1, 2, 3], "b": [6, None, 8], "c": ["a", "b", "c"], "d": [None, "e", "f"]}
+    )
+    df = df.with_columns(
+        [
+            pl.col("c").cast(pl.Categorical).alias("e"),
+            pl.col("d").cast(pl.Categorical).alias("f"),
+        ]
+    )
+    pd_out = df.to_pandas()
+    pd_out_dtypes_expected = [
+        np.int64,
+        np.float64,
+        np.object_,
+        np.object_,
+        pd.CategoricalDtype(categories=["a", "b", "c"], ordered=False),
+        pd.CategoricalDtype(categories=["e", "f"], ordered=False),
+    ]
+    assert pd_out.dtypes.to_list() == pd_out_dtypes_expected
+
+    try:
+        pd_pa_out = df.to_pandas(use_pyarrow_extension_array=True)
+        pd_pa_dtypes_names = [dtype.name for dtype in pd_pa_out.dtypes]
+        pd_pa_dtypes_names_expected = [
+            "int64[pyarrow]",
+            "int64[pyarrow]",
+            "large_string[pyarrow]",
+            "large_string[pyarrow]",
+            "dictionary<values=large_string, indices=int64, ordered=0>[pyarrow]",
+            "dictionary<values=large_string, indices=int64, ordered=0>[pyarrow]",
+        ]
+        assert pd_pa_dtypes_names == pd_pa_dtypes_names_expected
+    except ModuleNotFoundError:
+        # Skip test if Pandas 1.5.x is not installed.
+        pass
 
 
 def test_numpy_to_lit() -> None:
@@ -441,12 +514,29 @@ def test_from_empty_pandas() -> None:
     assert polars_df.dtypes == [pl.Float64, pl.Float64]
 
 
-def test_from_empty_pandas_strings() -> None:
+def test_from_empty_pandas_with_dtypes() -> None:
     df = pd.DataFrame(columns=["a", "b"])
     df["a"] = df["a"].astype(str)
     df["b"] = df["b"].astype(float)
-    df_pl = pl.from_pandas(df)
-    assert df_pl.dtypes == [pl.Utf8, pl.Float64]
+    assert pl.from_pandas(df).dtypes == [pl.Utf8, pl.Float64]
+
+    df = pl.DataFrame(
+        data=[],
+        schema={
+            "a": pl.Int32,
+            "b": pl.Datetime,
+            "c": pl.Float32,
+            "d": pl.Duration,
+            "e": pl.Utf8,
+        },
+    ).to_pandas()
+    assert pl.from_pandas(df).dtypes == [
+        pl.Int32,
+        pl.Datetime,
+        pl.Float32,
+        pl.Duration,
+        pl.Utf8,
+    ]
 
 
 def test_from_empty_arrow() -> None:
@@ -520,7 +610,7 @@ def test_cat_int_types_3500() -> None:
 
         for t in [int_dict_type, uint_dict_type]:
             s = cast(pl.Series, pl.from_arrow(pyarrow_array.cast(t)))
-            assert s.series_equal(pl.Series(["a", "a", "b"]).cast(pl.Categorical))
+            assert_series_equal(s, pl.Series(["a", "a", "b"]).cast(pl.Categorical))
 
 
 def test_from_pyarrow_chunked_array() -> None:
@@ -530,7 +620,7 @@ def test_from_pyarrow_chunked_array() -> None:
 
 
 def test_numpy_preserve_uint64_4112() -> None:
-    assert pl.DataFrame({"a": [1, 2, 3]}).with_column(
+    assert pl.DataFrame({"a": [1, 2, 3]}).with_columns(
         pl.col("a").hash()
     ).to_numpy().dtype == np.dtype("uint64")
 
@@ -546,6 +636,38 @@ def test_arrow_list_null_5697() -> None:
     df = pl.from_arrow(pa_table)
     pa_table = df.to_arrow()
     # again to polars to test the schema
-    assert pl.from_arrow(pa_table,).schema == {  # type: ignore[union-attr]
+    assert pl.from_arrow(pa_table).schema == {  # type: ignore[union-attr]
         "mycol": pl.List(pl.Null)
     }
+
+
+def test_from_pandas_null_struct_6412() -> None:
+    data = [
+        {
+            "a": {
+                "b": None,
+            },
+        },
+        {"a": None},
+    ]
+    df_pandas = pd.DataFrame(data)
+    assert pl.from_pandas(df_pandas).to_dict(False) == {"a": [{"b": None}, {"b": None}]}
+
+
+@typing.no_type_check
+def test_from_pyarrow_map() -> None:
+    pa_table = pa.table(
+        [[1, 2], [[("a", "something")], [("a", "else"), ("b", "another key")]]],
+        schema=pa.schema(
+            [("idx", pa.int16()), ("mapping", pa.map_(pa.string(), pa.string()))]
+        ),
+    )
+
+    df = pl.from_arrow(pa_table)
+    assert df.to_dict(False) == {
+        "idx": [1, 2],
+        "mapping": [
+            [{"key": "a", "value": "something"}],
+            [{"key": "a", "value": "else"}, {"key": "b", "value": "another key"}],
+        ],
+    }
