@@ -9,7 +9,7 @@ import pandas as pd
 import pytest
 
 import polars as pl
-import polars.testing
+from polars.testing import assert_frame_equal, assert_series_equal
 
 if TYPE_CHECKING:
     from polars.internals.type_aliases import JoinStrategy
@@ -74,38 +74,35 @@ def test_join_same_cat_src() -> None:
     }
 
 
-def test_sorted_merge_joins() -> None:
-    for reverse in [False, True]:
-        n = 30
-        df_a = pl.DataFrame(
-            {"a": np.sort(np.random.randint(0, n // 2, n))}
-        ).with_row_count("row_a")
+@pytest.mark.parametrize("reverse", [False, True])
+def test_sorted_merge_joins(reverse: bool) -> None:
+    n = 30
+    df_a = pl.DataFrame({"a": np.sort(np.random.randint(0, n // 2, n))}).with_row_count(
+        "row_a"
+    )
+    df_b = pl.DataFrame(
+        {"a": np.sort(np.random.randint(0, n // 2, n // 2))}
+    ).with_row_count("row_b")
 
-        df_b = pl.DataFrame(
-            {"a": np.sort(np.random.randint(0, n // 2, n // 2))}
-        ).with_row_count("row_b")
+    if reverse:
+        df_a = df_a.select(pl.all().reverse())
+        df_b = df_b.select(pl.all().reverse())
 
-        if reverse:
-            df_a = df_a.select(pl.all().reverse())
-            df_b = df_b.select(pl.all().reverse())
+    join_strategies: list[JoinStrategy] = ["left", "inner"]
+    for cast_to in [int, str, float]:
+        for how in join_strategies:
+            df_a_ = df_a.with_columns(pl.col("a").cast(cast_to))
+            df_b_ = df_b.with_columns(pl.col("a").cast(cast_to))
 
-        join_strategies: list[JoinStrategy] = ["left", "inner"]
-        for cast_to in [int, str, float]:
-            for how in join_strategies:
-                df_a_ = df_a.with_columns(pl.col("a").cast(cast_to))
-                df_b_ = df_b.with_columns(pl.col("a").cast(cast_to))
+            # hash join
+            out_hash_join = df_a_.join(df_b_, on="a", how=how)
 
-                # hash join
-                out_hash_join = df_a_.join(df_b_, on="a", how=how)
+            # sorted merge join
+            out_sorted_merge_join = df_a_.with_columns(
+                pl.col("a").set_sorted(reverse)
+            ).join(df_b_.with_columns(pl.col("a").set_sorted(reverse)), on="a", how=how)
 
-                # sorted merge join
-                out_sorted_merge_join = df_a_.with_columns(
-                    pl.col("a").set_sorted(reverse)
-                ).join(
-                    df_b_.with_columns(pl.col("a").set_sorted(reverse)), on="a", how=how
-                )
-
-                assert out_hash_join.frame_equal(out_sorted_merge_join)
+            assert_frame_equal(out_hash_join, out_sorted_merge_join)
 
 
 def test_join_negative_integers() -> None:
@@ -339,11 +336,11 @@ def test_join() -> None:
     )
 
     joined = df_left.join(df_right, left_on="a", right_on="a").sort("a")
-    assert joined["b"].series_equal(pl.Series("b", [1, 3, 2, 2]))
+    assert_series_equal(joined["b"], pl.Series("b", [1, 3, 2, 2]))
 
     joined = df_left.join(df_right, left_on="a", right_on="a", how="left").sort("a")
     assert joined["c_right"].is_null().sum() == 1
-    assert joined["b"].series_equal(pl.Series("b", [1, 3, 2, 2, 4]))
+    assert_series_equal(joined["b"], pl.Series("b", [1, 3, 2, 2, 4]))
 
     joined = df_left.join(df_right, left_on="a", right_on="a", how="outer").sort("a")
     assert joined["c_right"].null_count() == 1
@@ -373,7 +370,7 @@ def test_join() -> None:
 
     cols = ["a", "b", "bar", "ham"]
     assert lazy_join.shape == eager_join.shape
-    assert lazy_join.sort(by=cols).frame_equal(eager_join.sort(by=cols))
+    assert_frame_equal(lazy_join.sort(by=cols), eager_join.sort(by=cols))
 
 
 def test_joins_dispatch() -> None:
@@ -539,18 +536,19 @@ def test_sorted_flag_after_joins() -> None:
 @typing.no_type_check
 def test_jit_sort_joins() -> None:
     n = 200
+    # Explicitly specify numpy dtype because of different defaults on Windows
     dfa = pd.DataFrame(
         {
-            "a": np.random.randint(0, 100, n),
-            "b": np.arange(0, n),
+            "a": np.random.randint(0, 100, n, dtype=np.int64),
+            "b": np.arange(0, n, dtype=np.int64),
         }
     )
 
     n = 40
     dfb = pd.DataFrame(
         {
-            "a": np.random.randint(0, 100, n),
-            "b": np.arange(0, n),
+            "a": np.random.randint(0, 100, n, dtype=np.int64),
+            "b": np.arange(0, n, dtype=np.int64),
         }
     )
     dfa_pl = pl.from_pandas(dfa).sort("a")
@@ -564,7 +562,7 @@ def test_jit_sort_joins() -> None:
         pl_result = dfa_pl.join(dfb_pl, on="a", how=how).sort(["a", "b"])
 
         a = pl.from_pandas(pd_result).with_columns(pl.all().cast(int)).sort(["a", "b"])
-        assert a.frame_equal(pl_result, null_equal=True)
+        assert_frame_equal(a, pl_result)
         assert pl_result["a"].flags["SORTED_ASC"]
 
         # left key sorted right is not
@@ -573,7 +571,7 @@ def test_jit_sort_joins() -> None:
         pl_result = dfb_pl.join(dfa_pl, on="a", how=how).sort(["a", "b"])
 
         a = pl.from_pandas(pd_result).with_columns(pl.all().cast(int)).sort(["a", "b"])
-        assert a.frame_equal(pl_result, null_equal=True)
+        assert_frame_equal(a, pl_result)
         assert pl_result["a"].flags["SORTED_ASC"]
 
 
@@ -617,7 +615,7 @@ def test_asof_join_schema_5684() -> None:
     projected_result = q.select(pl.all()).collect()
     result = q.collect()
 
-    assert projected_result.frame_equal(result)
+    assert_frame_equal(projected_result, result)
     assert (
         q.schema
         == projected_result.schema
@@ -770,3 +768,18 @@ def test_semi_join_projection_pushdown_6455() -> None:
         "id": [1, 2],
         "value": [2, 4],
     }
+
+
+def test_update() -> None:
+    df = pl.DataFrame({"A": [1, 2, 3, 4], "B": [400, 500, 600, 700]})
+
+    new_df = pl.DataFrame({"B": [4, None, 6], "C": [7, 8, 9]})
+
+    assert df.update(new_df).to_dict(False) == {
+        "A": [1, 2, 3, 4],
+        "B": [4, 500, 6, 700],
+    }
+    df1 = pl.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]})
+    df2 = pl.DataFrame({"a": [2, 3], "b": [8, 9]})
+
+    assert df1.update(df2, on="a").to_dict(False) == {"a": [1, 2, 3], "b": [4, 8, 9]}
