@@ -215,22 +215,25 @@ def test_to_frame() -> None:
 def test_bitwise_ops() -> None:
     a = pl.Series([True, False, True])
     b = pl.Series([False, True, True])
-    assert (a & b).series_equal(pl.Series([False, False, True]))
-    assert (a | b).series_equal(pl.Series([True, True, True]))
-    assert (a ^ b).series_equal(pl.Series([True, True, False]))
-    assert (~a).series_equal(pl.Series([False, True, False]))
+    assert_series_equal((a & b), pl.Series([False, False, True]))
+    assert_series_equal((a | b), pl.Series([True, True, True]))
+    assert_series_equal((a ^ b), pl.Series([True, True, False]))
+    assert_series_equal((~a), pl.Series([False, True, False]))
 
     # rand/rxor/ror we trigger by casting the left hand to a list here in the test
     # Note that the type annotations only allow Series to be passed in, but there is
     # specific code to deal with non-Series inputs.
-    assert (True & a).series_equal(  # type: ignore[operator]
-        pl.Series([True, False, True])
+    assert_series_equal(
+        (True & a),  # type: ignore[operator]
+        pl.Series([True, False, True]),
     )
-    assert (True | a).series_equal(  # type: ignore[operator]
-        pl.Series([True, True, True])
+    assert_series_equal(
+        (True | a),  # type: ignore[operator]
+        pl.Series([True, True, True]),
     )
-    assert (True ^ a).series_equal(  # type: ignore[operator]
-        pl.Series([False, True, False])
+    assert_series_equal(
+        (True ^ a),  # type: ignore[operator]
+        pl.Series([False, True, False]),
     )
 
 
@@ -252,7 +255,7 @@ def test_equality() -> None:
     assert (a > b).sum() == 0
     assert (a < b).sum() == 0
     assert a.sum() == 3
-    assert a.series_equal(b)
+    assert_series_equal(a, b)
 
     a = pl.Series("name", ["ham", "foo", "bar"])
     assert_series_equal((a == "ham"), pl.Series("name", [True, False, False]))
@@ -300,16 +303,15 @@ def test_arithmetic(s: pl.Series) -> None:
 
     # integer division
     assert_series_equal(1 / a, pl.Series([1.0, 0.5]))
-    if s.dtype == Int64:
-        expected = pl.Series([1, 0])
-    else:
-        expected = pl.Series([1.0, 0.5])
+    expected = pl.Series([1, 0]) if s.dtype == Int64 else pl.Series([1.0, 0.5])
     assert_series_equal(1 // a, expected)
     # modulo
     assert ((1 % a) == [0, 1]).sum() == 2
     assert ((a % 1) == [0, 0]).sum() == 2
     # negate
     assert (-a == [-1, -2]).sum() == 2
+    # unary plus
+    assert (+a == a).all()
     # wrong dtypes in rhs operands
     assert ((1.0 - a) == [0.0, -1.0]).sum() == 2
     assert ((1.0 / a) == [1.0, 0.5]).sum() == 2
@@ -338,6 +340,11 @@ def test_arithmetic(s: pl.Series) -> None:
         2 % a
     with pytest.raises(ValueError):
         2**a
+    with pytest.raises(ValueError):
+        +a
+    a = pl.Series("a", [""])
+    with pytest.raises(ValueError):
+        +a
 
 
 def test_arithmetic_empty() -> None:
@@ -389,7 +396,7 @@ def test_append_extend() -> None:
     b = pl.Series("b", [8, 9, None])
     a.append(b, append_chunks=False)
     expected = pl.Series("a", [1, 2, 8, 9, None])
-    assert a.series_equal(expected, null_equal=True)
+    assert_series_equal(a, expected)
     assert a.n_chunks() == 1
 
 
@@ -404,7 +411,7 @@ def test_various() -> None:
     assert len(a) == 2
 
     a.append(a.clone())
-    assert a.series_equal(pl.Series("b", [1, 2, 1, 2]))
+    assert_series_equal(a, pl.Series("b", [1, 2, 1, 2]))
 
     a = pl.Series("a", range(20))
     assert a.head(5).len() == 5
@@ -413,11 +420,11 @@ def test_various() -> None:
 
     a = pl.Series("a", [2, 1, 4])
     a.sort(in_place=True)
-    assert a.series_equal(pl.Series("a", [1, 2, 4]))
+    assert_series_equal(a, pl.Series("a", [1, 2, 4]))
     a = pl.Series("a", [2, 1, 1, 4, 4, 4])
     assert_series_equal(a.arg_unique(), pl.Series("a", [0, 1, 3], dtype=UInt32))
 
-    assert a.take([2, 3]).series_equal(pl.Series("a", [1, 4]))
+    assert_series_equal(a.take([2, 3]), pl.Series("a", [1, 4]))
     assert a.is_numeric()
 
     a = pl.Series("bool", [True, False])
@@ -463,11 +470,21 @@ def test_to_pandas() -> None:
         assert b.isnull().sum() == 1
 
         if a.dtype == pl.List:
-            vals = [(None if x is None else x.tolist()) for x in b]
+            vals_b = [(None if x is None else x.tolist()) for x in b]
         else:
-            vals = b.replace({np.nan: None}).values.tolist()  # type: ignore[union-attr]
+            vals_b = b.replace({np.nan: None}).values.tolist()  # type: ignore[union-attr]
 
-        assert vals == test_data
+        assert vals_b == test_data
+
+        try:
+            c = a.to_pandas(use_pyarrow_extension_array=True)
+            assert a.name == c.name
+            assert c.isnull().sum() == 1
+            vals_c = [None if x is pd.NA else x for x in c.tolist()]
+            assert vals_c == test_data
+        except ModuleNotFoundError:
+            # Skip test if Pandas 1.5.x is not installed.
+            pass
 
 
 def test_to_python() -> None:
@@ -741,7 +758,7 @@ def test_set_np_array(dtype: Any) -> None:
     assert_series_equal(a, pl.Series("a", [4, 2, 4]))
 
 
-@pytest.mark.parametrize("idx", [[0, 2], (0, 2)])  # noqa: PT007
+@pytest.mark.parametrize("idx", [[0, 2], (0, 2)])
 def test_set_list_and_tuple(idx: list[int] | tuple[int]) -> None:
     a = pl.Series("a", [1, 2, 3])
     a[idx] = 4
@@ -820,12 +837,8 @@ def test_fill_null() -> None:
 def test_fill_nan() -> None:
     nan = float("nan")
     a = pl.Series("a", [1.0, nan, 2.0, nan, 3.0])
-    assert a.fill_nan(None).series_equal(
-        pl.Series("a", [1.0, None, 2.0, None, 3.0]), null_equal=True
-    )
-    assert a.fill_nan(0).series_equal(
-        pl.Series("a", [1.0, 0.0, 2.0, 0.0, 3.0]), null_equal=True
-    )
+    assert_series_equal(a.fill_nan(None), pl.Series("a", [1.0, None, 2.0, None, 3.0]))
+    assert_series_equal(a.fill_nan(0), pl.Series("a", [1.0, 0.0, 2.0, 0.0, 3.0]))
 
 
 def test_apply() -> None:
@@ -887,11 +900,9 @@ def test_rolling() -> None:
     # 3099
     # test if we maintain proper dtype
     for dt in [pl.Float32, pl.Float64]:
-        assert (
-            pl.Series([1, 2, 3], dtype=dt)
-            .rolling_min(2, weights=[0.1, 0.2])
-            .series_equal(pl.Series([None, 0.1, 0.2], dtype=dt), True)
-        )
+        result = pl.Series([1, 2, 3], dtype=dt).rolling_min(2, weights=[0.1, 0.2])
+        expected = pl.Series([None, 0.1, 0.2], dtype=dt)
+        assert_series_equal(result, expected)
 
     df = pl.DataFrame({"val": [1.0, 2.0, 3.0, np.NaN, 5.0, 6.0, 7.0]})
 
@@ -903,18 +914,18 @@ def test_rolling() -> None:
         assert out.null_count() == 2
         assert np.isnan(out.to_numpy()).sum() == 5
 
-    expected = [None, None, 2.0, 3.0, 5.0, 6.0, 6.0]
+    expected_values = [None, None, 2.0, 3.0, 5.0, 6.0, 6.0]
     assert (
         df.with_columns(pl.col("val").rolling_median(window_size=3))
         .to_series()
         .to_list()
-        == expected
+        == expected_values
     )
     assert (
         df.with_columns(pl.col("val").rolling_quantile(0.5, window_size=3))
         .to_series()
         .to_list()
-        == expected
+        == expected_values
     )
 
     nan = float("nan")
@@ -1114,12 +1125,6 @@ def test_slice() -> None:
         assert s[py_slice].to_list() == s.to_list()[py_slice]
 
 
-def test_str_slice() -> None:
-    df = pl.DataFrame({"a": ["foobar", "barfoo"]})
-    assert df["a"].str.slice(-3).to_list() == ["bar", "foo"]
-    assert df.select([pl.col("a").str.slice(2, 4)])["a"].to_list() == ["obar", "rfoo"]
-
-
 def test_arange_expr() -> None:
     df = pl.DataFrame({"a": ["foobar", "barfoo"]})
     out = df.select([pl.arange(0, pl.col("a").count() * 10)])
@@ -1184,24 +1189,6 @@ def test_mode() -> None:
     assert df.select([pl.col("a").mode()])["a"].to_list() == [1]
 
 
-def test_jsonpath_single() -> None:
-    s = pl.Series(['{"a":"1"}', None, '{"a":2}', '{"a":2.1}', '{"a":true}'])
-    expected = pl.Series(["1", None, "2", "2.1", "true"])
-    assert_series_equal(s.str.json_path_match("$.a"), expected)
-
-
-def test_extract_regex() -> None:
-    s = pl.Series(
-        [
-            "http://vote.com/ballon_dor?candidate=messi&ref=polars",
-            "http://vote.com/ballon_dor?candidat=jorginho&ref=polars",
-            "http://vote.com/ballon_dor?candidate=ronaldo&ref=polars",
-        ]
-    )
-    expected = pl.Series(["messi", None, "ronaldo"])
-    assert_series_equal(s.str.extract(r"candidate=(\w+)", 1), expected)
-
-
 def test_rank() -> None:
     s = pl.Series("a", [1, 2, 3, 2, 2, 3, 0])
 
@@ -1297,7 +1284,7 @@ def test_sqrt() -> None:
 
 def test_range() -> None:
     s1 = pl.Series("a", [1, 2, 3, 2, 2, 3, 0])
-    assert s1[2:5].series_equal(s1[range(2, 5)])
+    assert_series_equal(s1[2:5], s1[range(2, 5)])
 
     ranges = [range(-2, 1), range(3), range(2, 8, 2)]
 
@@ -1315,7 +1302,7 @@ def test_range() -> None:
     assert s3.dtype == pl.List(pl.List(pl.Int64))
 
     df = pl.DataFrame([s1])
-    assert df[2:5].frame_equal(df[range(2, 5)])
+    assert_frame_equal(df[2:5], df[range(2, 5)])
 
 
 def test_strict_cast() -> None:
@@ -1331,16 +1318,18 @@ def test_list_concat() -> None:
     expected = pl.Series("a", [[1, 2, 3, 4, 5]])
 
     out = s0.arr.concat([s1])
-    assert out.series_equal(expected)
+    assert_series_equal(out, expected)
 
     out = s0.arr.concat(s1)
-    assert out.series_equal(expected)
+    assert_series_equal(out, expected)
 
     df = pl.DataFrame([s0, s1])
-    assert df.select(pl.concat_list(["a", "b"]).alias("a"))["a"].series_equal(expected)
-    assert df.select(pl.col("a").arr.concat("b").alias("a"))["a"].series_equal(expected)
-    assert df.select(pl.col("a").arr.concat(["b"]).alias("a"))["a"].series_equal(
-        expected
+    assert_series_equal(df.select(pl.concat_list(["a", "b"]).alias("a"))["a"], expected)
+    assert_series_equal(
+        df.select(pl.col("a").arr.concat("b").alias("a"))["a"], expected
+    )
+    assert_series_equal(
+        df.select(pl.col("a").arr.concat(["b"]).alias("a"))["a"], expected
     )
 
 
@@ -1500,7 +1489,7 @@ def test_from_sequences(monkeypatch: Any) -> None:
         a = pl.Series("a", vals)
         monkeypatch.setattr(pl.internals.series.series, "_PYARROW_AVAILABLE", True)
         b = pl.Series("a", vals)
-        assert a.series_equal(b, null_equal=True)
+        assert_series_equal(a, b)
         assert a.to_list() == vals
 
 
@@ -1596,16 +1585,21 @@ def test_abs() -> None:
 def test_to_dummies() -> None:
     s = pl.Series("a", [1, 2, 3])
     result = s.to_dummies()
-    expected = pl.DataFrame({"a_1": [1, 0, 0], "a_2": [0, 1, 0], "a_3": [0, 0, 1]})
-    assert result.frame_equal(expected)
+    expected = pl.DataFrame(
+        {"a_1": [1, 0, 0], "a_2": [0, 1, 0], "a_3": [0, 0, 1]},
+        schema={"a_1": pl.UInt8, "a_2": pl.UInt8, "a_3": pl.UInt8},
+    )
+    assert_frame_equal(result, expected)
 
 
 def test_value_counts() -> None:
     s = pl.Series("a", [1, 2, 2, 3])
     result = s.value_counts()
-    expected = pl.DataFrame({"a": [1, 2, 3], "counts": [1, 2, 1]})
-    result_sorted: pl.DataFrame = result.sort("a")
-    assert result_sorted.frame_equal(expected)
+    expected = pl.DataFrame(
+        {"a": [1, 2, 3], "counts": [1, 2, 1]}, schema_overrides={"counts": pl.UInt32}
+    )
+    result_sorted = result.sort("a")
+    assert_frame_equal(result_sorted, expected)
 
 
 def test_chunk_lengths() -> None:
@@ -1617,30 +1611,30 @@ def test_chunk_lengths() -> None:
 
 def test_limit() -> None:
     s = pl.Series("a", [1, 2, 3])
-    assert s.limit(2).series_equal(pl.Series("a", [1, 2]))
+    assert_series_equal(s.limit(2), pl.Series("a", [1, 2]))
 
 
 def test_filter() -> None:
     s = pl.Series("a", [1, 2, 3])
     mask = pl.Series("", [True, False, True])
-    assert s.filter(mask).series_equal(pl.Series("a", [1, 3]))
+    assert_series_equal(s.filter(mask), pl.Series("a", [1, 3]))
 
-    assert s.filter([True, False, True]).series_equal(pl.Series("a", [1, 3]))
+    assert_series_equal(s.filter([True, False, True]), pl.Series("a", [1, 3]))
 
 
 def test_take_every() -> None:
     s = pl.Series("a", [1, 2, 3, 4])
-    assert s.take_every(2).series_equal(pl.Series("a", [1, 3]))
+    assert_series_equal(s.take_every(2), pl.Series("a", [1, 3]))
 
 
 def test_argsort() -> None:
     s = pl.Series("a", [5, 3, 4, 1, 2])
     expected = pl.Series("a", [3, 4, 1, 2, 0], dtype=UInt32)
 
-    assert s.argsort().series_equal(expected)
+    assert_series_equal(s.argsort(), expected)
 
     expected_reverse = pl.Series("a", [0, 2, 1, 4, 3], dtype=UInt32)
-    assert s.argsort(True).series_equal(expected_reverse)
+    assert_series_equal(s.argsort(True), expected_reverse)
 
 
 def test_arg_min_and_arg_max() -> None:
@@ -1649,46 +1643,48 @@ def test_arg_min_and_arg_max() -> None:
     assert s.arg_max() == 0
 
     s = pl.Series([None, True, False, True])
-    assert s.arg_min() == 2
+    assert s.arg_min() == 0
     assert s.arg_max() == 1
     s = pl.Series([None, None], dtype=pl.Boolean)
-    assert s.arg_min() is None
-    assert s.arg_max() is None
+    assert s.arg_min() == 0
+    assert s.arg_max() == 0
     s = pl.Series([True, True])
     assert s.arg_min() == 0
     assert s.arg_max() == 0
     s = pl.Series([False, False])
     assert s.arg_min() == 0
     assert s.arg_max() == 0
+    s = pl.Series(["a", "c", "b"])
+    assert s.arg_min() == 0
+    assert s.arg_max() == 1
 
 
 def test_is_null_is_not_null() -> None:
     s = pl.Series("a", [1.0, 2.0, 3.0, None])
-    assert s.is_null().series_equal(pl.Series("a", [False, False, False, True]))
-    assert s.is_not_null().series_equal(pl.Series("a", [True, True, True, False]))
+    assert_series_equal(s.is_null(), pl.Series("a", [False, False, False, True]))
+    assert_series_equal(s.is_not_null(), pl.Series("a", [True, True, True, False]))
 
 
 def test_is_finite_is_infinite() -> None:
     s = pl.Series("a", [1.0, 2.0, np.inf])
-
-    s.is_finite().series_equal(pl.Series("a", [True, True, False]))
-    s.is_infinite().series_equal(pl.Series("a", [False, False, True]))
+    assert_series_equal(s.is_finite(), pl.Series("a", [True, True, False]))
+    assert_series_equal(s.is_infinite(), pl.Series("a", [False, False, True]))
 
 
 def test_is_nan_is_not_nan() -> None:
     s = pl.Series("a", [1.0, 2.0, 3.0, np.NaN])
-    assert s.is_nan().series_equal(pl.Series("a", [False, False, False, True]))
-    assert s.is_not_nan().series_equal(pl.Series("a", [True, True, True, False]))
+    assert_series_equal(s.is_nan(), pl.Series("a", [False, False, False, True]))
+    assert_series_equal(s.is_not_nan(), pl.Series("a", [True, True, True, False]))
 
 
 def test_is_unique() -> None:
     s = pl.Series("a", [1, 2, 2, 3])
-    assert s.is_unique().series_equal(pl.Series("a", [True, False, False, True]))
+    assert_series_equal(s.is_unique(), pl.Series("a", [True, False, False, True]))
 
 
 def test_is_duplicated() -> None:
     s = pl.Series("a", [1, 2, 2, 3])
-    assert s.is_duplicated().series_equal(pl.Series("a", [False, True, True, False]))
+    assert_series_equal(s.is_duplicated(), pl.Series("a", [False, True, True, False]))
 
 
 def test_dot() -> None:
@@ -1745,197 +1741,6 @@ def test_shrink_to_fit() -> None:
     assert s is not sf
 
 
-def test_str_concat() -> None:
-    s = pl.Series(["1", None, "2"])
-    result = s.str.concat()
-    expected = pl.Series(["1-null-2"])
-    assert_series_equal(result, expected)
-
-
-def test_str_lengths() -> None:
-    s = pl.Series(["Café", None, "345", "東京"])
-    expected = pl.Series([5, None, 3, 6], dtype=UInt32)
-    assert_series_equal(s.str.lengths(), expected)
-
-
-def test_str_n_chars() -> None:
-    s = pl.Series(["Café", None, "345", "東京"])
-    expected = pl.Series([4, None, 3, 2], dtype=UInt32)
-    assert_series_equal(s.str.n_chars(), expected)
-
-
-def test_str_contains() -> None:
-    s = pl.Series(["messi", "ronaldo", "ibrahimovic"])
-    expected = pl.Series([True, False, False])
-    assert_series_equal(s.str.contains("mes"), expected)
-
-
-def test_str_encode() -> None:
-    s = pl.Series(["foo", "bar", None])
-    hex_encoded = pl.Series(["666f6f", "626172", None])
-    base64_encoded = pl.Series(["Zm9v", "YmFy", None])
-    assert_series_equal(s.str.encode("hex"), hex_encoded)
-    assert_series_equal(s.str.encode("base64"), base64_encoded)
-    with pytest.raises(ValueError):
-        s.str.encode("utf8")  # type: ignore[arg-type]
-
-
-def test_str_decode() -> None:
-    hex_encoded = pl.Series(["666f6f", "626172", None])
-    base64_encoded = pl.Series(["Zm9v", "YmFy", None])
-    expected = pl.Series([b"foo", b"bar", None])
-
-    assert_series_equal(hex_encoded.str.decode("hex"), expected)
-    assert_series_equal(base64_encoded.str.decode("base64"), expected)
-
-
-def test_str_decode_exception() -> None:
-    s = pl.Series(["not a valid", "626172", None])
-    with pytest.raises(Exception):
-        s.str.decode(encoding="hex")
-    with pytest.raises(Exception):
-        s.str.decode(encoding="base64")
-    with pytest.raises(ValueError):
-        s.str.decode("utf8")  # type: ignore[arg-type]
-
-
-def test_str_replace_str_replace_all() -> None:
-    s = pl.Series(["hello", "world", "test", "root"])
-    expected = pl.Series(["hell0", "w0rld", "test", "r0ot"])
-    assert_series_equal(s.str.replace("o", "0"), expected)
-
-    expected = pl.Series(["hell0", "w0rld", "test", "r00t"])
-    assert_series_equal(s.str.replace_all("o", "0"), expected)
-
-
-def test_str_to_lowercase() -> None:
-    s = pl.Series(["Hello", "WORLD"])
-    expected = pl.Series(["hello", "world"])
-    assert_series_equal(s.str.to_lowercase(), expected)
-
-
-def test_str_to_uppercase() -> None:
-    s = pl.Series(["Hello", "WORLD"])
-    expected = pl.Series(["HELLO", "WORLD"])
-    assert_series_equal(s.str.to_uppercase(), expected)
-
-
-def test_str_strip() -> None:
-    s = pl.Series([" hello ", "world\t "])
-    expected = pl.Series(["hello", "world"])
-    assert_series_equal(s.str.strip(), expected)
-
-    expected = pl.Series(["hello", "worl"])
-    assert_series_equal(s.str.strip().str.strip("d"), expected)
-
-    expected = pl.Series(["ell", "rld\t"])
-    assert_series_equal(s.str.strip(" hwo"), expected)
-
-
-def test_str_lstrip() -> None:
-    s = pl.Series([" hello ", "\t world"])
-    expected = pl.Series(["hello ", "world"])
-    assert_series_equal(s.str.lstrip(), expected)
-
-    expected = pl.Series(["ello ", "world"])
-    assert_series_equal(s.str.lstrip().str.lstrip("h"), expected)
-
-    expected = pl.Series(["ello ", "\t world"])
-    assert_series_equal(s.str.lstrip("hw "), expected)
-
-
-def test_str_rstrip() -> None:
-    s = pl.Series([" hello ", "world\t "])
-    expected = pl.Series([" hello", "world"])
-    assert_series_equal(s.str.rstrip(), expected)
-
-    expected = pl.Series([" hell", "world"])
-    assert_series_equal(s.str.rstrip().str.rstrip("o"), expected)
-
-    expected = pl.Series([" he", "wor"])
-    assert_series_equal(s.str.rstrip("odl \t"), expected)
-
-
-def test_str_strip_whitespace() -> None:
-    s = pl.Series("a", ["trailing  ", "  leading", "  both  "])
-
-    expected = pl.Series("a", ["trailing", "  leading", "  both"])
-    assert_series_equal(s.str.rstrip(), expected)
-
-    expected = pl.Series("a", ["trailing  ", "leading", "both  "])
-    assert_series_equal(s.str.lstrip(), expected)
-
-    expected = pl.Series("a", ["trailing", "leading", "both"])
-    assert_series_equal(s.str.strip(), expected)
-
-
-def test_str_strptime() -> None:
-    s = pl.Series(["2020-01-01", "2020-02-02"])
-    expected = pl.Series([date(2020, 1, 1), date(2020, 2, 2)])
-    assert_series_equal(s.str.strptime(pl.Date, "%Y-%m-%d"), expected)
-
-    s = pl.Series(["2020-01-01 00:00:00", "2020-02-02 03:20:10"])
-    expected = pl.Series(
-        [datetime(2020, 1, 1, 0, 0, 0), datetime(2020, 2, 2, 3, 20, 10)]
-    )
-    assert_series_equal(s.str.strptime(pl.Datetime, "%Y-%m-%d %H:%M:%S"), expected)
-
-    s = pl.Series(["00:00:00", "03:20:10"])
-    expected = pl.Series([0, 12010000000000], dtype=pl.Time)
-    assert_series_equal(s.str.strptime(pl.Time, "%H:%M:%S"), expected)
-
-
-def test_dt_strftime() -> None:
-    s = pl.Series("a", [10000, 20000, 30000], dtype=pl.Date)
-    assert s.dtype == pl.Date
-    expected = pl.Series("a", ["1997-05-19", "2024-10-04", "2052-02-20"])
-    assert_series_equal(s.dt.strftime("%F"), expected)
-
-
-def test_dt_year_month_week_day_ordinal_day() -> None:
-    s = pl.Series("a", [10000, 20000, 30000], dtype=pl.Date)
-
-    assert_series_equal(s.dt.year(), pl.Series("a", [1997, 2024, 2052], dtype=Int32))
-
-    assert_series_equal(s.dt.month(), pl.Series("a", [5, 10, 2], dtype=UInt32))
-    assert_series_equal(s.dt.weekday(), pl.Series("a", [1, 5, 2], dtype=UInt32))
-    assert_series_equal(s.dt.week(), pl.Series("a", [21, 40, 8], dtype=UInt32))
-    assert_series_equal(s.dt.day(), pl.Series("a", [19, 4, 20], dtype=UInt32))
-    assert_series_equal(
-        s.dt.ordinal_day(), pl.Series("a", [139, 278, 51], dtype=UInt32)
-    )
-
-    assert s.dt.median() == date(2024, 10, 4)
-    assert s.dt.mean() == date(2024, 10, 4)
-
-
-def test_dt_datetimes() -> None:
-    s = pl.Series(["2020-01-01 00:00:00.000000000", "2020-02-02 03:20:10.987654321"])
-    s = s.str.strptime(pl.Datetime, fmt="%Y-%m-%d %H:%M:%S.%9f")
-
-    # hours, minutes, seconds, milliseconds, microseconds, and nanoseconds
-    assert_series_equal(s.dt.hour(), pl.Series("", [0, 3], dtype=UInt32))
-    assert_series_equal(s.dt.minute(), pl.Series("", [0, 20], dtype=UInt32))
-    assert_series_equal(s.dt.second(), pl.Series("", [0, 10], dtype=UInt32))
-    assert_series_equal(s.dt.millisecond(), pl.Series("", [0, 987], dtype=UInt32))
-    assert_series_equal(s.dt.microsecond(), pl.Series("", [0, 987654], dtype=UInt32))
-    assert_series_equal(s.dt.nanosecond(), pl.Series("", [0, 987654321], dtype=UInt32))
-
-    # epoch methods
-    assert_series_equal(s.dt.epoch(tu="d"), pl.Series("", [18262, 18294], dtype=Int32))
-    assert_series_equal(
-        s.dt.epoch(tu="s"), pl.Series("", [1_577_836_800, 1_580_613_610], dtype=Int64)
-    )
-    assert_series_equal(
-        s.dt.epoch(tu="ms"),
-        pl.Series("", [1_577_836_800_000, 1_580_613_610_000], dtype=Int64),
-    )
-    # fractional seconds
-    assert_series_equal(
-        s.dt.second(fractional=True), pl.Series("", [0.0, 10.987654321], dtype=Float64)
-    )
-
-
 @pytest.mark.parametrize("unit", ["ns", "us", "ms"])
 def test_cast_datetime_to_time(unit: TimeUnit) -> None:
     a = pl.Series(
@@ -1968,17 +1773,17 @@ def test_reshape() -> None:
     expected = pl.Series("a", [[1, 2], [3, 4]])
     assert_series_equal(out, expected)
     out = s.reshape((2, 2))
-    assert out.series_equal(expected)
+    assert_series_equal(out, expected)
     out = s.reshape((2, -1))
-    assert out.series_equal(expected)
+    assert_series_equal(out, expected)
 
     out = s.reshape((-1, 1))
     expected = pl.Series("a", [[1], [2], [3], [4]])
-    assert out.series_equal(expected)
+    assert_series_equal(out, expected)
 
     # test lazy_dispatch
     out = pl.select(pl.lit(s).reshape((-1, 1))).to_series()
-    assert out.series_equal(expected)
+    assert_series_equal(out, expected)
 
 
 def test_init_categorical() -> None:
@@ -2036,8 +1841,8 @@ def test_is_between_datetime() -> None:
     expected = pl.Series("a", [False, True])
 
     # only on the expression api
-    result = s.to_frame().with_columns(pl.col("*").is_between(start, end))["is_between"]
-    assert_series_equal(result.rename("a"), expected)
+    result = s.to_frame().with_columns(pl.col("*").is_between(start, end)).to_series()
+    assert_series_equal(result, expected)
 
 
 @pytest.mark.parametrize(
@@ -2059,8 +1864,18 @@ def test_is_between_datetime() -> None:
 )
 @pytest.mark.filterwarnings("ignore:invalid value encountered:RuntimeWarning")
 def test_trigonometric(f: str) -> None:
-    s = pl.Series("a", [0.0, math.pi])
-    expected = pl.Series("a", getattr(np, f)(s.to_numpy()))
+    s = pl.Series("a", [0.0, math.pi, None, math.nan])
+    expected = (
+        pl.Series("a", getattr(np, f)(s.to_numpy()))
+        .to_frame()
+        .with_columns(
+            pl.when(s.is_null())  # type: ignore[arg-type]
+            .then(None)
+            .otherwise(pl.col("a"))
+            .alias("a")
+        )
+        .to_series()
+    )
     result = getattr(s, f)()
     assert_series_equal(result, expected)
 
@@ -2081,21 +1896,40 @@ def test_ewm_mean() -> None:
     s = pl.Series([2, 5, 3])
 
     expected = pl.Series([2.0, 4.0, 3.4285714285714284])
-    assert_series_equal(s.ewm_mean(alpha=0.5, adjust=True), expected)
+    assert_series_equal(s.ewm_mean(alpha=0.5, adjust=True, ignore_nulls=True), expected)
+    assert_series_equal(
+        s.ewm_mean(alpha=0.5, adjust=True, ignore_nulls=False), expected
+    )
 
     expected = pl.Series([2.0, 3.8, 3.421053])
-    assert_series_equal(s.ewm_mean(com=2.0, adjust=True), expected)
+    assert_series_equal(s.ewm_mean(com=2.0, adjust=True, ignore_nulls=True), expected)
+    assert_series_equal(s.ewm_mean(com=2.0, adjust=True, ignore_nulls=False), expected)
 
     expected = pl.Series([2.0, 3.5, 3.25])
-    assert_series_equal(s.ewm_mean(alpha=0.5, adjust=False), expected)
+    assert_series_equal(
+        s.ewm_mean(alpha=0.5, adjust=False, ignore_nulls=True), expected
+    )
+    assert_series_equal(
+        s.ewm_mean(alpha=0.5, adjust=False, ignore_nulls=False), expected
+    )
 
     s = pl.Series([2, 3, 5, 7, 4])
 
     expected = pl.Series([None, 2.666667, 4.0, 5.6, 4.774194])
-    assert_series_equal(s.ewm_mean(alpha=0.5, adjust=True, min_periods=2), expected)
+    assert_series_equal(
+        s.ewm_mean(alpha=0.5, adjust=True, min_periods=2, ignore_nulls=True), expected
+    )
+    assert_series_equal(
+        s.ewm_mean(alpha=0.5, adjust=True, min_periods=2, ignore_nulls=False), expected
+    )
 
     expected = pl.Series([None, None, 4.0, 5.6, 4.774194])
-    assert_series_equal(s.ewm_mean(alpha=0.5, adjust=True, min_periods=3), expected)
+    assert_series_equal(
+        s.ewm_mean(alpha=0.5, adjust=True, min_periods=3, ignore_nulls=True), expected
+    )
+    assert_series_equal(
+        s.ewm_mean(alpha=0.5, adjust=True, min_periods=3, ignore_nulls=False), expected
+    )
 
     s = pl.Series([None, 1.0, 5.0, 7.0, None, 2.0, 5.0, 4])
 
@@ -2111,10 +1945,32 @@ def test_ewm_mean() -> None:
             4.174603174603175,
         ],
     )
-    assert_series_equal(s.ewm_mean(alpha=0.5, adjust=True, min_periods=1), expected)
+    assert_series_equal(s.ewm_mean(alpha=0.5, adjust=True, ignore_nulls=True), expected)
+    expected = pl.Series(
+        [
+            None,
+            1.0,
+            3.666666666666667,
+            5.571428571428571,
+            5.571428571428571,
+            3.08695652173913,
+            4.2,
+            4.092436974789916,
+        ]
+    )
+    assert_series_equal(
+        s.ewm_mean(alpha=0.5, adjust=True, ignore_nulls=False), expected
+    )
 
     expected = pl.Series([None, 1.0, 3.0, 5.0, 5.0, 3.5, 4.25, 4.125])
-    assert_series_equal(s.ewm_mean(alpha=0.5, adjust=False, min_periods=1), expected)
+    assert_series_equal(
+        s.ewm_mean(alpha=0.5, adjust=False, ignore_nulls=True), expected
+    )
+
+    expected = pl.Series([None, 1.0, 3.0, 5.0, 5.0, 3.0, 4.0, 4.0])
+    assert_series_equal(
+        s.ewm_mean(alpha=0.5, adjust=False, ignore_nulls=False), expected
+    )
 
 
 def test_ewm_mean_leading_nulls() -> None:
@@ -2142,21 +1998,31 @@ def test_ewm_mean_min_periods() -> None:
     series = pl.Series([1.0, None, 2.0, None, 3.0])
 
     ewm_mean = series.ewm_mean(alpha=0.5, min_periods=1)
-    assert ewm_mean.to_list() == [
-        1.0,
-        1.0,
-        1.6666666666666665,
-        1.6666666666666665,
-        2.4285714285714284,
-    ]
+    assert_series_equal(
+        ewm_mean,
+        pl.Series(
+            [
+                1.0,
+                1.0,
+                1.6666666666666665,
+                1.6666666666666665,
+                2.4285714285714284,
+            ]
+        ),
+    )
     ewm_mean = series.ewm_mean(alpha=0.5, min_periods=2)
-    assert ewm_mean.to_list() == [
-        None,
-        None,
-        1.6666666666666665,
-        1.6666666666666665,
-        2.4285714285714284,
-    ]
+    assert_series_equal(
+        ewm_mean,
+        pl.Series(
+            [
+                None,
+                None,
+                1.6666666666666665,
+                1.6666666666666665,
+                2.4285714285714284,
+            ]
+        ),
+    )
 
 
 def test_ewm_std_var() -> None:
@@ -2198,9 +2064,14 @@ def test_ewm_param_validation() -> None:
     ("const", "dtype"),
     [
         (1, pl.Int8),
-        (date.today(), pl.Date),
-        ("xyz", pl.Utf8),
+        (4, pl.UInt32),
+        (4.5, pl.Float32),
         (None, pl.Float64),
+        ("白鵬翔", pl.Utf8),
+        (date.today(), pl.Date),
+        (datetime.now(), pl.Datetime("ns")),
+        (time(23, 59, 59), pl.Time),
+        (timedelta(hours=7, seconds=123), pl.Duration("ms")),
     ],
 )
 def test_extend_constant(const: Any, dtype: pl.PolarsDataType) -> None:
@@ -2255,31 +2126,7 @@ def test_duration_arithmetic() -> None:
         df1 = pl.select((s + d).alias("d_offset"))
         df2 = pl.select((d + s).alias("d_offset"))
         assert df1["d_offset"].to_list() == expected_values
-        assert df1["d_offset"].series_equal(df2["d_offset"])
-
-
-def test_duration_extract_times() -> None:
-    a = pl.Series("a", [datetime(2021, 1, 1)])
-    b = pl.Series("b", [datetime(2021, 1, 2)])
-
-    duration = b - a
-    expected = pl.Series("b", [1])
-    assert_series_equal(duration.dt.days(), expected)
-
-    expected = pl.Series("b", [24])
-    assert_series_equal(duration.dt.hours(), expected)
-
-    expected = pl.Series("b", [3600 * 24])
-    assert_series_equal(duration.dt.seconds(), expected)
-
-    expected = pl.Series("b", [3600 * 24 * int(1e3)])
-    assert_series_equal(duration.dt.milliseconds(), expected)
-
-    expected = pl.Series("b", [3600 * 24 * int(1e6)])
-    assert_series_equal(duration.dt.microseconds(), expected)
-
-    expected = pl.Series("b", [3600 * 24 * int(1e9)])
-    assert_series_equal(duration.dt.nanoseconds(), expected)
+        assert_series_equal(df1["d_offset"], df2["d_offset"])
 
 
 def test_mean_overflow() -> None:
@@ -2287,22 +2134,6 @@ def test_mean_overflow() -> None:
     assert arr.mean() == 255.0
 
 
-def test_str_split() -> None:
-    a = pl.Series("a", ["a, b", "a", "ab,c,de"])
-    for out in [a.str.split(","), pl.select(pl.lit(a).str.split(",")).to_series()]:
-        assert out[0].to_list() == ["a", " b"]
-        assert out[1].to_list() == ["a"]
-        assert out[2].to_list() == ["ab", "c", "de"]
-
-    for out in [
-        a.str.split(",", inclusive=True),
-        pl.select(pl.lit(a).str.split(",", inclusive=True)).to_series(),
-    ]:
-        assert out[0].to_list() == ["a,", " b"]
-        assert out[1].to_list() == ["a"]
-        assert out[2].to_list() == ["ab,", "c,", "de"]
-
-
 def test_sign() -> None:
     # Integers
     a = pl.Series("a", [-9, -0, 0, 4, None])
@@ -2346,17 +2177,6 @@ def test_cumulative_eval() -> None:
     assert_series_equal(s.cumulative_eval(expr3), expected3)
 
 
-def test_drop_nan_ignore_null_3525() -> None:
-    df = pl.DataFrame({"a": [1.0, float("NaN"), 2.0, None, 3.0, 4.0]})
-    assert df.select(pl.col("a").drop_nans()).to_series().to_list() == [
-        1.0,
-        2.0,
-        None,
-        3.0,
-        4.0,
-    ]
-
-
 def test_reverse() -> None:
     s = pl.Series("values", [1, 2, 3, 4, 5])
     assert s.reverse().to_list() == [5, 4, 3, 2, 1]
@@ -2485,8 +2305,8 @@ def test_get_chunks() -> None:
     a = pl.Series("a", [1, 2])
     b = pl.Series("a", [3, 4])
     chunks = pl.concat([a, b], rechunk=False).get_chunks()
-    assert chunks[0].series_equal(a)
-    assert chunks[1].series_equal(b)
+    assert_series_equal(chunks[0], a)
+    assert_series_equal(chunks[1], b)
 
 
 def test_item() -> None:
@@ -2512,3 +2332,15 @@ def test_ptr() -> None:
 
     ptr2 = s2.rechunk()._get_ptr()
     assert ptr != ptr2
+
+
+def test_null_comparisons() -> None:
+    s = pl.Series("s", [None, "str", "a"])
+    assert (s.shift() == s).null_count() == 0
+    assert (s.shift() != s).null_count() == 0
+
+
+def test_min_max_agg_on_str() -> None:
+    strings = ["b", "a", "x"]
+    s = pl.Series(strings)
+    assert (s.min(), s.max()) == ("a", "x")
